@@ -37,14 +37,14 @@ while ( ~< *DATA) {
     $_ = lc;
     if (my ($correct, $alias) = m/^\s*([^#\s]\S*)\s+(.*\S)/) {
         if ($correct eq '+') {$correct = $prev} else {$prev = $correct}
-        $map {$alias} = $correct;
+        %map {$alias} = $correct;
     }
 }
 
 #
 # Email addresses for we do not have names.
 #
-$map {$_} = "?" for 
+%map {$_} = "?" for 
     "agrow\100thegotonerd.com",
     "alexander_bluhm\100genua.de",
     "alexander_gernler\100genua.de",
@@ -90,7 +90,7 @@ $map {$_} = "?" for
 # Presumably deliberately?
 # 
 
-$map {$_} = '!' for
+%map {$_} = '!' for
      # Nick Ing-Simmons has passed away (2006-09-25).
      "nick\100ing-simmons.net",
      "nik\100tiuk.ti.com",
@@ -127,10 +127,10 @@ if (@authors) {
       next if m/^-- /;
       if (m/<([^>]+)>/) {
 	# Easy line.
-	$raw{$1}++;
+	%raw{$1}++;
       } elsif (m/^([-A-Za-z0-9 .\'--]+)[\t\n]/) {
 	# Name only
-	$untraced{$1}++;
+	%untraced{$1}++;
       } else {
 	chomp;
 	warn "Can't parse line '$_'";
@@ -138,12 +138,12 @@ if (@authors) {
     }
   }
   foreach (keys %raw) {
-    print "E-mail $_ occurs $raw{$_} times\n" if $raw{$_} +> 1;
+    print "E-mail $_ occurs %raw{$_} times\n" if %raw{$_} +> 1;
     $_ = lc $_;
-    $authors{$map{$_} || $_}++;
+    %authors{%map{$_} || $_}++;
   }
-  ++$authors{'!'};
-  ++$authors{'?'};
+  ++%authors{'!'};
+  ++%authors{'?'};
 }
 
 while ( ~< *ARGV) {
@@ -182,13 +182,13 @@ if ($rank) {
 } elsif (%authors) {
   my %missing;
   foreach (sort keys %patchers) {
-    next if $authors{$_};
+    next if %authors{$_};
     # Sort by number of patches, then name.
-    $missing{$patchers{$_}}->{$_}++;
+    %missing{%patchers{$_}}->{$_}++;
   }
   foreach my $patches (sort {$b <+> $a} keys %missing) {
     print "$patches patch(es)\n";
-    foreach my $author (sort keys %{$missing{$patches}}) {
+    foreach my $author (sort keys %{%missing{$patches}}) {
       print "  $author\n";
     }
   }
@@ -199,25 +199,25 @@ sub display_ordered {
   my @sorted;
   my $total;
   while (my ($name, $count) = each %$what) {
-    push @{$sorted[$count]}, $name;
+    push @{@sorted[$count]}, $name;
     $total += $count;
   }
 
   my $i = @sorted;
   return unless @sorted;
   my $sum = 0;
-  foreach my $i ($reverse ? 0 .. $#sorted : reverse 0 .. $#sorted) {
-    next unless $sorted[$i];
+  foreach my $i ($reverse ? 0 ..( @sorted-1) : reverse 0 ..( @sorted-1)) {
+    next unless @sorted[$i];
     my $prefix;
-    $sum += $i * @{$sorted[$i]};
+    $sum += $i * @{@sorted[$i]};
     # Value to display is either this one, or the cumulative sum.
     my $value = $cumulative ? $sum : $i;
     if ($percentage) {
-	$prefix = sprintf "%6.2f:\t", 100 * $value / $total;
+	$prefix = sprintf "\%6.2f:\t", 100 * $value / $total;
     } else {
 	$prefix = "$value:\t";
     }
-    print wrap ($prefix, "\t", join (" ", sort @{$sorted[$i]}), "\n");
+    print wrap ($prefix, "\t", join (" ", sort @{@sorted[$i]}), "\n");
   }
 }
 
@@ -231,15 +231,15 @@ sub process {
       s/^<//;
       s/>$//;
       $_ = lc $_;
-      $patchers{$map{$_} || $_}++;
+      %patchers{%map{$_} || $_}++;
     }
     # print "$patch: @authors\n";
-    ++$committers{$committer};
+    ++%committers{$committer};
   } else {
     # print "$patch: $committer\n";
     # Not entirely fair as this means that the maint pumpking scores for
     # everything intergrated that wasn't a third party patch in blead
-    $patchers{$committer}++;
+    %patchers{$committer}++;
   }
 }
 
