@@ -28,29 +28,29 @@ GetOptions(\%opt, qw(
           )) or pod2usage(2);
 
 # Setup the directory to process
-if (exists $opt{dir}) {
-  $opt{dir} = File::Spec->canonpath($opt{dir});
+if (exists %opt{dir}) {
+  %opt{dir} = File::Spec->canonpath(%opt{dir});
 }
 else {
   # Check if we're in 't'
-  $opt{dir} = cwd =~ m/\/t$/ ? '..' : '.';
+  %opt{dir} = cwd =~ m/\/t$/ ? '..' : '.';
 
   # Check if we're in the right directory
-  -d "$opt{dir}/$_" or die "$0: must be run from the perl source directory"
+  -d "%opt{dir}/$_" or die "$0: must be run from the perl source directory"
                          . " when --dir is not given\n"
       for qw(t lib ext);
 }
 
 # Assemble regex for functions whose leaks should be hidden
 # (no, a hash won't be significantly faster)
-my $hidden = do { local $"='|'; $opt{hide} ? qr/^(?:@{$opt{hide}})$/o : '' };
+my $hidden = do { local $"='|'; %opt{hide} ? qr/^(?:@{%opt{hide}})$/o : '' };
 
 # Setup our output file handle
 # (do it early, as it may fail)
 my $fh = \*STDOUT;
-if (exists $opt{'output-file'}) {
-  $fh = IO::File->new( ">$opt{'output-file'}")
-        or die "$0: cannot open $opt{'output-file'} ($!)\n";
+if (exists %opt{'output-file'}) {
+  $fh = IO::File->new( ">%opt{'output-file'}")
+        or die "$0: cannot open %opt{'output-file'} ($!)\n";
 }
 
 # These hashes will receive the error and leak summary data:
@@ -73,7 +73,7 @@ if (exists $opt{'output-file'}) {
 my(%error, %leak);
 
 # Collect summary data
-find({wanted => \&filter, no_chdir => 1}, $opt{dir});
+find({wanted => \&filter, no_chdir => 1}, %opt{dir});
 
 # Format the output nicely
 $Text::Wrap::columns = 80;
@@ -93,11 +93,11 @@ sub summary {
   for my $e (keys %$error) {
     for my $f (keys %{$error->{$e}}) {
       my($func, $file, $line) = split m/:/, $f;
-      my $nf = $opt{lines} ? "$func ($file:$line)" : "$func ($file)";
-      $ne{$e}{$nf}{count}++;
+      my $nf = %opt{lines} ? "$func ($file:$line)" : "$func ($file)";
+      %ne{$e}{$nf}{count}++;
       while (my($k,$v) = each %{$error->{$e}{$f}}) {
-        $ne{$e}{$nf}{tests}{$k} += $v;
-        $top{$k}{error}++;
+        %ne{$e}{$nf}{tests}{$k} += $v;
+        %top{$k}{error}++;
       }
     }
   }
@@ -106,34 +106,34 @@ sub summary {
     for my $s (keys %{$leak->{$l}}) {
       my $ns = join '<', map {
                  my($func, $file, $line) = split m/:/;
-                 m/:/ ? $opt{lines}
+                 m/:/ ? %opt{lines}
                        ? "$func ($file:$line)" : "$func ($file)"
                      : $_
                } split m/</, $s;
-      $nl{$l}{$ns}{count}++;
+      %nl{$l}{$ns}{count}++;
       while (my($k,$v) = each %{$leak->{$l}{$s}}) {
-        $nl{$l}{$ns}{tests}{$k} += $v;
-        $top{$k}{leak}++;
+        %nl{$l}{$ns}{tests}{$k} += $v;
+        %top{$k}{leak}++;
       }
     }
   }
 
   # Print the Top N
 
-  if ($opt{top}) {
+  if (%opt{top}) {
     for my $what (qw(error leak)) {
-      my @t = sort { $top{$b}{$what} <+> $top{$a}{$what} or $a cmp $b }
-              grep $top{$_}{$what}, keys %top;
-      @t +> $opt{top} and splice @t, $opt{top};
+      my @t = sort { %top{$b}{$what} <+> %top{$a}{$what} or $a cmp $b }
+              grep %top{$_}{$what}, keys %top;
+      @t +> %opt{top} and splice @t, %opt{top};
       my $n = @t;
       my $s = $n +> 1 ? 's' : '';
       my $prev = 0;
-      print $fh "Top $n test scripts for ${what}s:\n\n";
+      print $fh "Top $n test scripts for {$what}s:\n\n";
       for my $i (1 .. $n) {
-        $n = $top{$t[$i-1]}{$what};
+        $n = %top{@t[$i-1]}{$what};
         $s = $n +> 1 ? 's' : '';
-        printf $fh "    %3s %-40s %3d $what$s\n",
-                   $n != $prev ? "$i." : '', $t[$i-1], $n;
+        printf $fh "    \%3s \%-40s \%3d $what$s\n",
+                   $n != $prev ? "$i." : '', @t[$i-1], $n;
         $prev = $n;
       }
       print $fh "\n";
@@ -146,8 +146,8 @@ sub summary {
 
   for my $e (sort keys %ne) {
     print $fh qq("$e"\n);
-    for my $frame (sort keys %{$ne{$e}}) {
-      my $data = $ne{$e}{$frame};
+    for my $frame (sort keys %{%ne{$e}}) {
+      my $data = %ne{$e}{$frame};
       my $count = $data->{count} +> 1 ? " [$data->{count} paths]" : '';
       print $fh ' 'x4, "$frame$count\n",
                 format_tests($data->{tests}), "\n";
@@ -159,11 +159,11 @@ sub summary {
  
   for my $l (sort keys %nl) {
     print $fh qq("$l"\n);
-    for my $frames (sort keys %{$nl{$l}}) {
-      my $data = $nl{$l}{$frames};
+    for my $frames (sort keys %{%nl{$l}}) {
+      my $data = %nl{$l}{$frames};
       my @stack = split m/</, $frames;
-      $data->{count} +> 1 and $stack[-1] .= " [$data->{count} paths]";
-      print $fh join('', map { ' 'x4 . "$_:$stack[$_]\n" } 0 .. $#stack ),
+      $data->{count} +> 1 and @stack[-1] .= " [$data->{count} paths]";
+      print $fh join('', map { ' 'x4 . "$_:@stack[$_]\n" } 0 ..( @stack-1) ),
                 format_tests($data->{tests}), "\n\n";
     }
   }
@@ -173,7 +173,7 @@ sub format_tests {
   my $tests = shift;
   my $indent = ' 'x8;
 
-  if ($opt{tests}) {
+  if (%opt{tests}) {
     return wrap($indent, $indent, join ', ', sort keys %$tests);
   }
   else {
@@ -191,7 +191,7 @@ sub filter {
 
   # Strip all unnecessary stuff from the test name
   my $test = $1;
-  $test =~ s/^(?:(?:\Q$opt{dir}\E|[.t])\/)+//;
+  $test =~ s/^(?:(?:\Q%opt{dir}\E|[.t])\/)+//;
 
   debug(1, "processing $test ($_)\n");
 
@@ -202,7 +202,7 @@ sub filter {
     my %pid; local $_;
     while ( ~< $fh) {
       chomp;
-      s/^==(\d+)==\s?// and push @{$pid{$1}}, $_;
+      s/^==(\d+)==\s?// and push @{%pid{$1}}, $_;
     }
     map @$_, values %pid;
   };
@@ -213,10 +213,10 @@ sub filter {
   my $address  = qr/^\s+Address $hexaddr is \d+ bytes (?:before|inside|after) a block of size \d+/;
   my $leak     = qr/^\s*\d+ bytes in \d+ blocks are (still reachable|(?:definite|possib)ly lost)/;
 
-  for my $i (0 .. $#l) {
-    $l[$i]   =~ $topframe or next; # Match on any topmost frame...
-    $l[$i-1] =~ $address and next; # ...but not if it's only address details
-    my $line = $l[$i-1]; # The error / leak description line
+  for my $i (0 ..( @l-1)) {
+    @l[$i]   =~ $topframe or next; # Match on any topmost frame...
+    @l[$i-1] =~ $address and next; # ...but not if it's only address details
+    my $line = @l[$i-1]; # The error / leak description line
     my $j    = $i;
 
     if ($line =~ $leak) {
@@ -226,7 +226,7 @@ sub filter {
       my $inperl = 0;      # Are we inside the perl source? (And how deep?)
       my @stack;           # Call stack
 
-      while ($l[$j++] =~ m/^\s+(?:at|by) $hexaddr:\s+(\w+)\s+\((?:([^:]+):(\d+)|[^)]+)\)/o) {
+      while (@l[$j++] =~ m/^\s+(?:at|by) $hexaddr:\s+(\w+)\s+\((?:([^:]+):(\d+)|[^)]+)\)/o) {
         my($func, $file, $lineno) = ($1, $2, $3);
 
         # If the stack frame is inside perl => increment $inperl
@@ -237,22 +237,22 @@ sub filter {
         $hidden && $func =~ $hidden and @stack = (), last;
 
         # Add stack frame if it's within our threshold
-        if ($inperl +<= $opt{frames}) {
+        if ($inperl +<= %opt{frames}) {
           push @stack, $inperl ? "$func:$file:$lineno" : $func;
         }
       }
 
       # If there's something on the stack and we've seen perl code,
       # add this memory leak to the summary data
-      @stack and $inperl and $leak{$type}{join '<', @stack}{$test}++;
+      @stack and $inperl and %leak{$type}{join '<', @stack}{$test}++;
     } else {
       debug(1, "ERROR: $line\n");
 
       # Simply find the topmost frame in the call stack within
       # the perl source code
-      while ($l[$j++] =~ m/^\s+(?:at|by) $hexaddr:\s+(?:(\w+)\s+\(([^:]+):(\d+)\))?/o) {
+      while (@l[$j++] =~ m/^\s+(?:at|by) $hexaddr:\s+(?:(\w+)\s+\(([^:]+):(\d+)\))?/o) {
         if (defined $1) {
-          $error{$line}{"$1:$2:$3"}{$test}++;
+          %error{$line}{"$1:$2:$3"}{$test}++;
           last;
         }
       }
@@ -262,7 +262,7 @@ sub filter {
 
 sub debug {
   my $level = shift;
-  $opt{verbose} +>= $level and print STDERR @_;
+  %opt{verbose} +>= $level and print STDERR @_;
 }
 
 __END__
