@@ -32,7 +32,7 @@ $GzipError = '' ;
 @ISA    = qw(IO::Compress::RawDeflate Exporter);
 @EXPORT_OK = qw( $GzipError gzip ) ;
 %EXPORT_TAGS = %IO::Compress::RawDeflate::DEFLATE_CONSTANTS ;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+push @{ %EXPORT_TAGS{all} }, @EXPORT_OK ;
 Exporter::export_ok_tags('all');
 
 sub new
@@ -177,7 +177,7 @@ sub getFileInfo
     my $params = shift;
     my $filename = shift ;
 
-    my $defaultTime = (stat($filename))[9] ;
+    my $defaultTime = (stat($filename))[[9]] ;
 
     $params->value('Name' => $filename)
         if ! $params->parsed('Name') ;
