@@ -24,7 +24,7 @@ $RawInflateError = '';
 @EXPORT_OK = qw( $RawInflateError rawinflate ) ;
 %DEFLATE_CONSTANTS = ();
 %EXPORT_TAGS = %IO::Uncompress::Base::EXPORT_TAGS ;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+push @{ %EXPORT_TAGS{all} }, @EXPORT_OK ;
 Exporter::export_ok_tags('all');
 
 
@@ -289,7 +289,7 @@ sub zap
 
     my $headerLength = *$self->{Info}{HeaderLength};
     my $block_offset =  $headerLength + *$self->{Uncomp}->getLastBlockOffset();
-    $_[0] = $headerLength + *$self->{Uncomp}->getEndOffset();
+    @_[0] = $headerLength + *$self->{Uncomp}->getEndOffset();
     #printf "# End $_[0], headerlen $headerLength \n";;
     #printf "# block_offset $block_offset %x\n", $block_offset;
     my $byte ;
