@@ -31,7 +31,7 @@ my %NON_CONSTS = (map {($_,1)}
                      WIFEXITED WIFSIGNALED WIFSTOPPED WSTOPSIG WTERMSIG));
 
 for my $name (keys %NON_CONSTS) {
-    *{Symbol::fetch_glob($name)} = sub { int_macro_int($name, $_[0]) };
+    *{Symbol::fetch_glob($name)} = sub { int_macro_int($name, @_[0]) };
 }
 
 package POSIX::SigRt;
@@ -67,42 +67,42 @@ sub unimpl {
 
 sub assert {
     usage "assert(expr)" if @_ != 1;
-    if (!$_[0]) {
+    if (!@_[0]) {
 	die "Assertion failed";
     }
 }
 
 sub tolower {
     usage "tolower(string)" if @_ != 1;
-    lc($_[0]);
+    lc(@_[0]);
 }
 
 sub toupper {
     usage "toupper(string)" if @_ != 1;
-    uc($_[0]);
+    uc(@_[0]);
 }
 
 sub closedir {
     usage "closedir(dirhandle)" if @_ != 1;
-    CORE::closedir($_[0]);
+    CORE::closedir(@_[0]);
 }
 
 sub opendir {
     usage "opendir(directory)" if @_ != 1;
     my $dirhandle;
-    CORE::opendir($dirhandle, $_[0])
+    CORE::opendir($dirhandle, @_[0])
 	? $dirhandle
 	: undef;
 }
 
 sub readdir {
     usage "readdir(dirhandle)" if @_ != 1;
-    CORE::readdir($_[0]);
+    CORE::readdir(@_[0]);
 }
 
 sub rewinddir {
     usage "rewinddir(dirhandle)" if @_ != 1;
-    CORE::rewinddir($_[0]);
+    CORE::rewinddir(@_[0]);
 }
 
 sub errno {
@@ -112,72 +112,72 @@ sub errno {
 
 sub creat {
     usage "creat(filename, mode)" if @_ != 2;
-    &open($_[0], &O_WRONLY ^|^ &O_CREAT ^|^ &O_TRUNC, $_[1]);
+    &open(@_[0], &O_WRONLY ^|^ &O_CREAT ^|^ &O_TRUNC, @_[1]);
 }
 
 sub fcntl {
     usage "fcntl(filehandle, cmd, arg)" if @_ != 3;
-    CORE::fcntl($_[0], $_[1], $_[2]);
+    CORE::fcntl(@_[0], @_[1], @_[2]);
 }
 
 sub getgrgid {
     usage "getgrgid(gid)" if @_ != 1;
-    CORE::getgrgid($_[0]);
+    CORE::getgrgid(@_[0]);
 }
 
 sub getgrnam {
     usage "getgrnam(name)" if @_ != 1;
-    CORE::getgrnam($_[0]);
+    CORE::getgrnam(@_[0]);
 }
 
 sub atan2 {
     usage "atan2(x,y)" if @_ != 2;
-    CORE::atan2($_[0], $_[1]);
+    CORE::atan2(@_[0], @_[1]);
 }
 
 sub cos {
     usage "cos(x)" if @_ != 1;
-    CORE::cos($_[0]);
+    CORE::cos(@_[0]);
 }
 
 sub exp {
     usage "exp(x)" if @_ != 1;
-    CORE::exp($_[0]);
+    CORE::exp(@_[0]);
 }
 
 sub fabs {
     usage "fabs(x)" if @_ != 1;
-    CORE::abs($_[0]);
+    CORE::abs(@_[0]);
 }
 
 sub log {
     usage "log(x)" if @_ != 1;
-    CORE::log($_[0]);
+    CORE::log(@_[0]);
 }
 
 sub pow {
     usage "pow(x,exponent)" if @_ != 2;
-    $_[0] ** $_[1];
+    @_[0] ** @_[1];
 }
 
 sub sin {
     usage "sin(x)" if @_ != 1;
-    CORE::sin($_[0]);
+    CORE::sin(@_[0]);
 }
 
 sub sqrt {
     usage "sqrt(x)" if @_ != 1;
-    CORE::sqrt($_[0]);
+    CORE::sqrt(@_[0]);
 }
 
 sub getpwnam {
     usage "getpwnam(name)" if @_ != 1;
-    CORE::getpwnam($_[0]);
+    CORE::getpwnam(@_[0]);
 }
 
 sub getpwuid {
     usage "getpwuid(uid)" if @_ != 1;
-    CORE::getpwuid($_[0]);
+    CORE::getpwuid(@_[0]);
 }
 
 sub longjmp {
@@ -198,12 +198,12 @@ sub sigsetjmp {
 
 sub kill {
     usage "kill(pid, sig)" if @_ != 2;
-    CORE::kill $_[1], $_[0];
+    CORE::kill @_[1], @_[0];
 }
 
 sub raise {
     usage "raise(sig)" if @_ != 1;
-    CORE::kill $_[0], $$;	# Is this good enough?
+    CORE::kill @_[0], $$;	# Is this good enough?
 }
 
 sub offsetof {
@@ -300,7 +300,7 @@ sub fwrite {
 
 sub getc {
     usage "getc(handle)" if @_ != 1;
-    CORE::getc($_[0]);
+    CORE::getc(@_[0]);
 }
 
 sub getchar {
@@ -337,17 +337,17 @@ sub puts {
 
 sub remove {
     usage "remove(filename)" if @_ != 1;
-    (-d $_[0]) ? CORE::rmdir($_[0]) : CORE::unlink($_[0]);
+    (-d @_[0]) ? CORE::rmdir(@_[0]) : CORE::unlink(@_[0]);
 }
 
 sub rename {
     usage "rename(oldfilename, newfilename)" if @_ != 2;
-    CORE::rename($_[0], $_[1]);
+    CORE::rename(@_[0], @_[1]);
 }
 
 sub rewind {
     usage "rewind(filehandle)" if @_ != 1;
-    CORE::seek($_[0],0,0);
+    CORE::seek(@_[0],0,0);
 }
 
 sub scanf {
@@ -385,7 +385,7 @@ sub vsprintf {
 
 sub abs {
     usage "abs(x)" if @_ != 1;
-    CORE::abs($_[0]);
+    CORE::abs(@_[0]);
 }
 
 sub atexit {
@@ -413,12 +413,12 @@ sub calloc {
 }
 
 sub div {
-    unimpl "div() is C-specific, use /, % and int instead";
+    unimpl "div() is C-specific, use /, \% and int instead";
 }
 
 sub exit {
     usage "exit(status)" if @_ != 1;
-    CORE::exit($_[0]);
+    CORE::exit(@_[0]);
 }
 
 sub free {
@@ -427,7 +427,7 @@ sub free {
 
 sub getenv {
     usage "getenv(name)" if @_ != 1;
-    $ENV{$_[0]};
+    %ENV{@_[0]};
 }
 
 sub labs {
@@ -435,7 +435,7 @@ sub labs {
 }
 
 sub ldiv {
-    unimpl "ldiv() is C-specific, use /, % and int instead";
+    unimpl "ldiv() is C-specific, use /, \% and int instead";
 }
 
 sub malloc {
@@ -460,7 +460,7 @@ sub srand {
 
 sub system {
     usage "system(command)" if @_ != 1;
-    CORE::system($_[0]);
+    CORE::system(@_[0]);
 }
 
 sub memchr {
@@ -505,7 +505,7 @@ sub strcspn {
 
 sub strerror {
     usage "strerror(errno)" if @_ != 1;
-    local $! = $_[0];
+    local $! = @_[0];
     $! . "";
 }
 
@@ -539,7 +539,7 @@ sub strspn {
 
 sub strstr {
     usage "strstr(big, little)" if @_ != 2;
-    CORE::index($_[0], $_[1]);
+    CORE::index(@_[0], @_[1]);
 }
 
 sub strtok {
@@ -548,13 +548,13 @@ sub strtok {
 
 sub chmod {
     usage "chmod(mode, filename)" if @_ != 2;
-    CORE::chmod($_[0], $_[1]);
+    CORE::chmod(@_[0], @_[1]);
 }
 
 sub fstat {
     usage "fstat(fd)" if @_ != 1;
     local *TMP;
-    CORE::open(TMP, "<&", $_[0]);		# Gross.
+    CORE::open(TMP, "<&", @_[0]);		# Gross.
     my @l = CORE::stat(*TMP);
     CORE::close(TMP);
     @l;
@@ -562,17 +562,17 @@ sub fstat {
 
 sub mkdir {
     usage "mkdir(directoryname, mode)" if @_ != 2;
-    CORE::mkdir($_[0], $_[1]);
+    CORE::mkdir(@_[0], @_[1]);
 }
 
 sub stat {
     usage "stat(filename)" if @_ != 1;
-    CORE::stat($_[0]);
+    CORE::stat(@_[0]);
 }
 
 sub umask {
     usage "umask(mask)" if @_ != 1;
-    CORE::umask($_[0]);
+    CORE::umask(@_[0]);
 }
 
 sub wait {
@@ -582,17 +582,17 @@ sub wait {
 
 sub waitpid {
     usage "waitpid(pid, options)" if @_ != 2;
-    CORE::waitpid($_[0], $_[1]);
+    CORE::waitpid(@_[0], @_[1]);
 }
 
 sub gmtime {
     usage "gmtime(time)" if @_ != 1;
-    CORE::gmtime($_[0]);
+    CORE::gmtime(@_[0]);
 }
 
 sub localtime {
     usage "localtime(time)" if @_ != 1;
-    CORE::localtime($_[0]);
+    CORE::localtime(@_[0]);
 }
 
 sub time {
@@ -602,17 +602,17 @@ sub time {
 
 sub alarm {
     usage "alarm(seconds)" if @_ != 1;
-    CORE::alarm($_[0]);
+    CORE::alarm(@_[0]);
 }
 
 sub chdir {
     usage "chdir(directory)" if @_ != 1;
-    CORE::chdir($_[0]);
+    CORE::chdir(@_[0]);
 }
 
 sub chown {
     usage "chown(uid, gid, filename)" if @_ != 3;
-    CORE::chown($_[0], $_[1], $_[2]);
+    CORE::chown(@_[0], @_[1], @_[2]);
 }
 
 sub execl {
@@ -662,7 +662,7 @@ sub getgid {
 sub getgroups {
     usage "getgroups()" if @_ != 0;
     my %seen;
-    grep(!$seen{$_}++, split(' ', $) ));
+    grep(!%seen{$_}++, split(' ', $) ));
 }
 
 sub getlogin {
@@ -692,17 +692,17 @@ sub getuid {
 
 sub isatty {
     usage "isatty(filehandle)" if @_ != 1;
-    -t $_[0];
+    -t @_[0];
 }
 
 sub link {
     usage "link(oldfilename, newfilename)" if @_ != 2;
-    CORE::link($_[0], $_[1]);
+    CORE::link(@_[0], @_[1]);
 }
 
 sub rmdir {
     usage "rmdir(directoryname)" if @_ != 1;
-    CORE::rmdir($_[0]);
+    CORE::rmdir(@_[0]);
 }
 
 sub setbuf {
@@ -715,17 +715,17 @@ sub setvbuf {
 
 sub sleep {
     usage "sleep(seconds)" if @_ != 1;
-    $_[0] - CORE::sleep($_[0]);
+    @_[0] - CORE::sleep(@_[0]);
 }
 
 sub unlink {
     usage "unlink(filename)" if @_ != 1;
-    CORE::unlink($_[0]);
+    CORE::unlink(@_[0]);
 }
 
 sub utime {
     usage "utime(filename, atime, mtime)" if @_ != 3;
-    CORE::utime($_[1], $_[2], $_[0]);
+    CORE::utime(@_[1], @_[2], @_[0]);
 }
 
 sub load_imports {
@@ -882,7 +882,7 @@ sub load_imports {
 {
   # De-duplicate the export list: 
   my %export;
-  @export{map {@$_} values %EXPORT_TAGS} = ();
+  %export{[map {@$_} values %EXPORT_TAGS]} = ();
   # Doing the de-dup with a temporary hash has the advantage that the SVs in
   # @EXPORT are actually shared hash key sacalars, which will save some memory.
   push @EXPORT, keys %export;
@@ -952,11 +952,11 @@ require Exporter;
 
 package POSIX::SigAction;
 
-sub new { bless {HANDLER => $_[1], MASK => $_[2], FLAGS => $_[3] || 0, SAFE => 0}, $_[0] }
-sub handler { $_[0]->{HANDLER} = $_[1] if @_ +> 1; $_[0]->{HANDLER} };
-sub mask    { $_[0]->{MASK}    = $_[1] if @_ +> 1; $_[0]->{MASK} };
-sub flags   { $_[0]->{FLAGS}   = $_[1] if @_ +> 1; $_[0]->{FLAGS} };
-sub safe    { $_[0]->{SAFE}    = $_[1] if @_ +> 1; $_[0]->{SAFE} };
+sub new { bless {HANDLER => @_[1], MASK => @_[2], FLAGS => @_[3] || 0, SAFE => 0}, @_[0] }
+sub handler { @_[0]->{HANDLER} = @_[1] if @_ +> 1; @_[0]->{HANDLER} };
+sub mask    { @_[0]->{MASK}    = @_[1] if @_ +> 1; @_[0]->{MASK} };
+sub flags   { @_[0]->{FLAGS}   = @_[1] if @_ +> 1; @_[0]->{FLAGS} };
+sub safe    { @_[0]->{SAFE}    = @_[1] if @_ +> 1; @_[0]->{SAFE} };
 
 package POSIX::SigRt;
 
@@ -974,7 +974,7 @@ sub _croak {
 
 sub _getsig {
     &_croak;
-    my $rtsig = $_[0];
+    my $rtsig = @_[0];
     # Allow (SIGRT)?MIN( + n)?, a common idiom when doing these things in C.
     $rtsig = $_SIGRTMIN + ($1 || 0)
 	if $rtsig =~ m/^(?:(?:SIG)?RT)?MIN(\s*\+\s*(\d+))?$/;
@@ -982,14 +982,14 @@ sub _getsig {
 }
 
 sub _exist {
-    my $rtsig = _getsig($_[1]);
+    my $rtsig = _getsig(@_[1]);
     my $ok    = $rtsig +>= $_SIGRTMIN && $rtsig +<= $_SIGRTMAX;
     ($rtsig, $ok);
 }
 
 sub _check {
     my ($rtsig, $ok) = &_exist;
-    die "No POSIX::SigRt signal $_[1] (valid range SIGRTMIN..SIGRTMAX, or $_SIGRTMIN..$_SIGRTMAX)"
+    die "No POSIX::SigRt signal @_[1] (valid range SIGRTMIN..SIGRTMAX, or $_SIGRTMIN..$_SIGRTMAX)"
 	unless $ok;
     return $rtsig;
 }
@@ -1008,7 +1008,7 @@ sub FETCH  { my $rtsig = &_check;
 	     my $oa = POSIX::SigAction->new();
 	     POSIX::sigaction($rtsig, undef, $oa);
 	     return $oa->{HANDLER} }
-sub STORE  { my $rtsig = &_check; new($rtsig, $_[2], $SIGACTION_FLAGS) }
-sub DELETE { delete $SIG{ &_check } }
-sub CLEAR  { &_exist; delete @SIG{ &POSIX::SIGRTMIN .. &POSIX::SIGRTMAX } }
+sub STORE  { my $rtsig = &_check; new($rtsig, @_[2], $SIGACTION_FLAGS) }
+sub DELETE { delete %SIG{ &_check } }
+sub CLEAR  { &_exist; delete %SIG{[&POSIX::SIGRTMIN .. &POSIX::SIGRTMAX ]} }
 sub SCALAR { &_croak; $_sigrtn + 1 }
