@@ -6,7 +6,7 @@ for (@data) {
 	my ($pid, $cmd, $time, $cpu) = split;
 	$cmd =~ s/_/ /g;
 	print form
-		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{>>>>>>\}  \{>>.\}%",
+		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{>>>>>>\}  \{>>.\}\%",
 		  $pid,  $cmd,             $time,    $cpu;
 }
 
@@ -16,7 +16,7 @@ for (@data) {
 	my ($pid, $cmd, $time, $cpu) = split;
 	$cmd =~ s/_/ /g;
 	print form
-		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{]]]]]]\}   \{>\{5.2\}.<%\}",
+		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{]]]]]]\}   \{>\{5.2\}.<\%\}",
 		  $pid,  $cmd,             $time,    $cpu;
 }
 
@@ -27,7 +27,7 @@ for (@data) {
 	$cmd =~ s/_/ /g;
 	print form
 		 {single=>'%'},
-		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{]]]]]]\}  \{>>.\}%",
+		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{]]]]]]\}  \{>>.\}\%",
 		  $pid,  $cmd,             $time,    $cpu, '%';
 }
 
@@ -37,7 +37,7 @@ for (@data) {
 	my ($pid, $cmd, $time, $cpu) = split;
 	$cmd =~ s/_/ /g;
 	print form
-		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{]]]]]+\}  \{>>.\}%",
+		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{]]]]]+\}  \{>>.\}\%",
 		  $pid,  $cmd,             $time,    $cpu;
 }
 
@@ -46,7 +46,7 @@ print "---------------------------------------------\n";
 for (@data) {
 	my ($pid, $cmd, $time, $cpu) = split;
 	$cmd =~ s/_/ /g;
-	printf "%5d  %-16s  %8s  %5.1f%%\n",
+	printf "\%5d  \%-16s  \%8s  \%5.1f\%\%\n",
 		  $pid,  $cmd,  $time, $cpu;
 }
 
