@@ -46,37 +46,37 @@ sub split_like_shell {
 sub arg_defines {
   my ($self, %args) = @_;
   s/"/\\"/g foreach values %args;
-  return map qq{"-D$_=$args{$_}"}, keys %args;
+  return map qq{"-D$_=%args{$_}"}, keys %args;
 }
 
 sub compile {
   my ($self, %args) = @_;
   my $cf = $self->{config};
 
-  die "Missing 'source' argument to compile()" unless defined $args{source};
+  die "Missing 'source' argument to compile()" unless defined %args{source};
 
   my ($basename, $srcdir) =
-    ( File::Basename::fileparse($args{source}, '\.[^.]+$') )[0,1];
+    ( File::Basename::fileparse(%args{source}, '\.[^.]+$') )[[0,1]];
 
   $srcdir ||= File::Spec->curdir();
 
-  my @defines = $self->arg_defines( %{ $args{defines} || {} } );
+  my @defines = $self->arg_defines( %{ %args{defines} || {} } );
 
   my %spec = (
     srcdir      => $srcdir,
     builddir    => $srcdir,
     basename    => $basename,
-    source      => $args{source},
+    source      => %args{source},
     output      => File::Spec->catfile($srcdir, $basename) . $cf->{obj_ext},
     cc          => $cf->{cc},
     cflags      => [
                      $self->split_like_shell($cf->{ccflags}),
                      $self->split_like_shell($cf->{cccdlflags}),
-                     $self->split_like_shell($args{extra_compiler_flags}),
+                     $self->split_like_shell(%args{extra_compiler_flags}),
                    ],
     optimize    => [ $self->split_like_shell($cf->{optimize})    ],
     defines     => \@defines,
-    includes    => [ @{$args{include_dirs} || []} ],
+    includes    => [ @{%args{include_dirs} || []} ],
     perlinc     => [
                      $self->perl_inc(),
                      $self->split_like_shell($cf->{incpath}),
@@ -85,19 +85,19 @@ sub compile {
   );
 
   $self->normalize_filespecs(
-    \$spec{source},
-    \$spec{output},
-     $spec{includes},
-     $spec{perlinc},
+    \%spec{source},
+    \%spec{output},
+     %spec{includes},
+     %spec{perlinc},
   );
 
   my @cmds = $self->format_compiler_cmd(%spec);
   while ( my $cmd = shift @cmds ) {
     $self->do_system( @$cmd )
-      or die "error building $cf->{dlext} file from '$args{source}'";
+      or die "error building $cf->{dlext} file from '%args{source}'";
   }
 
-  (my $out = $spec{output}) =~ tr/'"//d;
+  (my $out = %spec{output}) =~ tr/'"//d;
   return $out;
 }
 
@@ -107,12 +107,12 @@ sub link {
   my ($self, %args) = @_;
   my $cf = $self->{config};
 
-  my @objects = ( ref $args{objects} eq 'ARRAY' ? @{$args{objects}} : $args{objects} );
-  my $to = join '', (File::Spec->splitpath($objects[0]))[0,1];
+  my @objects = ( ref %args{objects} eq 'ARRAY' ? @{%args{objects}} : %args{objects} );
+  my $to = join '', (File::Spec->splitpath(@objects[0]))[[0,1]];
   $to ||= File::Spec->curdir();
 
-  (my $file_base = $args{module_name}) =~ s/.*:://;
-  my $output = $args{lib_file} ||
+  (my $file_base = %args{module_name}) =~ s/.*:://;
+  my $output = %args{lib_file} ||
     File::Spec->catfile($to, "$file_base.$cf->{dlext}");
 
   # if running in perl source tree, look for libs there, not installed
@@ -132,66 +132,66 @@ sub link {
     perllibs      => [ $self->split_like_shell($cf->{perllibs})  ],
     libpath       => [ $self->split_like_shell($cf->{libpth})    ],
     lddlflags     => [ $self->split_like_shell($lddlflags) ],
-    other_ldflags => [ $self->split_like_shell($args{extra_linker_flags} || '') ],
+    other_ldflags => [ $self->split_like_shell(%args{extra_linker_flags} || '') ],
     use_scripts   => 1, # XXX provide user option to change this???
   );
 
-  unless ( $spec{basename} ) {
-    ($spec{basename} = $args{module_name}) =~ s/.*:://;
+  unless ( %spec{basename} ) {
+    (%spec{basename} = %args{module_name}) =~ s/.*:://;
   }
 
-  $spec{srcdir}   = File::Spec->canonpath( $spec{srcdir}   );
-  $spec{builddir} = File::Spec->canonpath( $spec{builddir} );
+  %spec{srcdir}   = File::Spec->canonpath( %spec{srcdir}   );
+  %spec{builddir} = File::Spec->canonpath( %spec{builddir} );
 
-  $spec{output}    ||= File::Spec->catfile( $spec{builddir},
-                                            $spec{basename}  . '.'.$cf->{dlext}   );
-  $spec{manifest}  ||= File::Spec->catfile( $spec{builddir},
-                                            $spec{basename}  . '.'.$cf->{dlext}.'.manifest');
-  $spec{implib}    ||= File::Spec->catfile( $spec{builddir},
-                                            $spec{basename}  . $cf->{lib_ext} );
-  $spec{explib}    ||= File::Spec->catfile( $spec{builddir},
-                                            $spec{basename}  . '.exp'  );
+  %spec{output}    ||= File::Spec->catfile( %spec{builddir},
+                                            %spec{basename}  . '.'.$cf->{dlext}   );
+  %spec{manifest}  ||= File::Spec->catfile( %spec{builddir},
+                                            %spec{basename}  . '.'.$cf->{dlext}.'.manifest');
+  %spec{implib}    ||= File::Spec->catfile( %spec{builddir},
+                                            %spec{basename}  . $cf->{lib_ext} );
+  %spec{explib}    ||= File::Spec->catfile( %spec{builddir},
+                                            %spec{basename}  . '.exp'  );
   if ($cf->{cc} eq 'cl') {
-    $spec{dbg_file}  ||= File::Spec->catfile( $spec{builddir},
-                                            $spec{basename}  . '.pdb'  );
+    %spec{dbg_file}  ||= File::Spec->catfile( %spec{builddir},
+                                            %spec{basename}  . '.pdb'  );
   }
   elsif ($cf->{cc} eq 'bcc32') {
-    $spec{dbg_file}  ||= File::Spec->catfile( $spec{builddir},
-                                            $spec{basename}  . '.tds'  );
+    %spec{dbg_file}  ||= File::Spec->catfile( %spec{builddir},
+                                            %spec{basename}  . '.tds'  );
   }
-  $spec{def_file}  ||= File::Spec->catfile( $spec{srcdir}  ,
-                                            $spec{basename}  . '.def'  );
-  $spec{base_file} ||= File::Spec->catfile( $spec{srcdir}  ,
-                                            $spec{basename}  . '.base' );
+  %spec{def_file}  ||= File::Spec->catfile( %spec{srcdir}  ,
+                                            %spec{basename}  . '.def'  );
+  %spec{base_file} ||= File::Spec->catfile( %spec{srcdir}  ,
+                                            %spec{basename}  . '.base' );
 
   $self->add_to_cleanup(
     grep defined,
-    @{[ @spec{qw(manifest implib explib dbg_file def_file base_file map_file)} ]}
+    @{[ %spec{[qw(manifest implib explib dbg_file def_file base_file map_file)]} ]}
   );
 
   foreach my $opt ( qw(output manifest implib explib dbg_file def_file map_file base_file) ) {
-    $self->normalize_filespecs( \$spec{$opt} );
+    $self->normalize_filespecs( \%spec{$opt} );
   }
 
   foreach my $opt ( qw(libpath startup objects) ) {
-    $self->normalize_filespecs( $spec{$opt} );
+    $self->normalize_filespecs( %spec{$opt} );
   }
 
-  (my $def_base = $spec{def_file}) =~ tr/'"//d;
+  (my $def_base = %spec{def_file}) =~ tr/'"//d;
   $def_base =~ s/\.def$//;
-  $self->prelink( dl_name => $args{module_name},
+  $self->prelink( dl_name => %args{module_name},
                   dl_file => $def_base,
-                  dl_base => $spec{basename} );
+                  dl_base => %spec{basename} );
 
   my @cmds = $self->format_linker_cmd(%spec);
   while ( my $cmd = shift @cmds ) {
     $self->do_system( @$cmd );
   }
 
-  $spec{output} =~ tr/'"//d;
+  %spec{output} =~ tr/'"//d;
   return wantarray
-    ? grep defined, @spec{qw[output manifest implib explib dbg_file def_file map_file base_file]}
-    : $spec{output};
+    ? grep defined, %spec{[qw[output manifest implib explib dbg_file def_file map_file base_file]]}
+    : %spec{output};
 }
 
 # canonize & quote paths
@@ -253,31 +253,31 @@ package ExtUtils::CBuilder::Platform::Windows::MSVC;
 sub format_compiler_cmd {
   my ($self, %spec) = @_;
 
-  foreach my $path ( @{ $spec{includes} || [] },
-                     @{ $spec{perlinc}  || [] } ) {
+  foreach my $path ( @{ %spec{includes} || [] },
+                     @{ %spec{perlinc}  || [] } ) {
     $path = '-I' . $path;
   }
 
   %spec = $self->write_compiler_script(%spec)
-    if $spec{use_scripts};
+    if %spec{use_scripts};
 
   return [ grep {defined && length} (
-    $spec{cc},'-nologo','-c',
-    @{$spec{includes}}      ,
-    @{$spec{cflags}}        ,
-    @{$spec{optimize}}      ,
-    @{$spec{defines}}       ,
-    @{$spec{perlinc}}       ,
-    "-Fo$spec{output}"      ,
-    $spec{source}           ,
+    %spec{cc},'-nologo','-c',
+    @{%spec{includes}}      ,
+    @{%spec{cflags}}        ,
+    @{%spec{optimize}}      ,
+    @{%spec{defines}}       ,
+    @{%spec{perlinc}}       ,
+    "-Fo%spec{output}"      ,
+    %spec{source}           ,
   ) ];
 }
 
 sub write_compiler_script {
   my ($self, %spec) = @_;
 
-  my $script = File::Spec->catfile( $spec{srcdir},
-                                    $spec{basename} . '.ccs' );
+  my $script = File::Spec->catfile( %spec{srcdir},
+                                    %spec{basename} . '.ccs' );
 
   $self->add_to_cleanup($script);
   print "Generating script '$script'\n" if !$self->{quiet};
@@ -289,12 +289,12 @@ sub write_compiler_script {
     map { ref $_ ? @{$_} : $_ }
     grep defined,
     delete(
-      @spec{ qw(includes cflags optimize defines perlinc) } )
+      %spec{[qw(includes cflags optimize defines perlinc) ]} )
   );
 
   close SCRIPT;
 
-  push @{$spec{includes}}, '@"' . $script . '"';
+  push @{%spec{includes}}, '@"' . $script . '"';
 
   return %spec;
 }
@@ -303,42 +303,42 @@ sub format_linker_cmd {
   my ($self, %spec) = @_;
   my $cf = $self->{config};
 
-  foreach my $path ( @{$spec{libpath}} ) {
+  foreach my $path ( @{%spec{libpath}} ) {
     $path = "-libpath:$path";
   }
 
-  my $output = $spec{output};
+  my $output = %spec{output};
 
-  $spec{def_file}  &&= '-def:'      . $spec{def_file};
-  $spec{output}    &&= '-out:'      . $spec{output};
-  $spec{manifest}  &&= '-manifest ' . $spec{manifest};
-  $spec{implib}    &&= '-implib:'   . $spec{implib};
-  $spec{map_file}  &&= '-map:'      . $spec{map_file};
+  %spec{def_file}  &&= '-def:'      . %spec{def_file};
+  %spec{output}    &&= '-out:'      . %spec{output};
+  %spec{manifest}  &&= '-manifest ' . %spec{manifest};
+  %spec{implib}    &&= '-implib:'   . %spec{implib};
+  %spec{map_file}  &&= '-map:'      . %spec{map_file};
 
   %spec = $self->write_linker_script(%spec)
-    if $spec{use_scripts};
+    if %spec{use_scripts};
 
   my @cmds; # Stores the series of commands needed to build the module.
 
   push @cmds, [ grep {defined && length} (
-    $spec{ld}               ,
-    @{$spec{lddlflags}}     ,
-    @{$spec{libpath}}       ,
-    @{$spec{other_ldflags}} ,
-    @{$spec{startup}}       ,
-    @{$spec{objects}}       ,
-    $spec{map_file}         ,
-    $spec{libperl}          ,
-    @{$spec{perllibs}}      ,
-    $spec{def_file}         ,
-    $spec{implib}           ,
-    $spec{output}           ,
+    %spec{ld}               ,
+    @{%spec{lddlflags}}     ,
+    @{%spec{libpath}}       ,
+    @{%spec{other_ldflags}} ,
+    @{%spec{startup}}       ,
+    @{%spec{objects}}       ,
+    %spec{map_file}         ,
+    %spec{libperl}          ,
+    @{%spec{perllibs}}      ,
+    %spec{def_file}         ,
+    %spec{implib}           ,
+    %spec{output}           ,
   ) ];
 
   # Embed the manifest file for VC 2005 (aka VC 8) or higher, but not for the 64-bit Platform SDK compiler
   if ($cf->{ivsize} == 4 && $cf->{cc} eq 'cl' and $cf->{ccversion} =~ m/^(\d+)/ and $1 +>= 14) {
     push @cmds, [
-      'mt', '-nologo', $spec{manifest}, '-outputresource:' . "$output;2"
+      'mt', '-nologo', %spec{manifest}, '-outputresource:' . "$output;2"
     ];
   }
 
@@ -348,8 +348,8 @@ sub format_linker_cmd {
 sub write_linker_script {
   my ($self, %spec) = @_;
 
-  my $script = File::Spec->catfile( $spec{srcdir},
-                                    $spec{basename} . '.lds' );
+  my $script = File::Spec->catfile( %spec{srcdir},
+                                    %spec{basename} . '.lds' );
 
   $self->add_to_cleanup($script);
 
@@ -362,14 +362,14 @@ sub write_linker_script {
     map { ref $_ ? @{$_} : $_ }
     grep defined,
     delete(
-      @spec{ qw(lddlflags libpath other_ldflags
+      %spec{[qw(lddlflags libpath other_ldflags
                 startup objects libperl perllibs
-                def_file implib map_file)            } )
+                def_file implib map_file)            ]} )
   );
 
   close SCRIPT;
 
-  push @{$spec{lddlflags}}, '@"' . $script . '"';
+  push @{%spec{lddlflags}}, '@"' . $script . '"';
 
   return %spec;
 }
@@ -382,31 +382,31 @@ package ExtUtils::CBuilder::Platform::Windows::BCC;
 sub format_compiler_cmd {
   my ($self, %spec) = @_;
 
-  foreach my $path ( @{ $spec{includes} || [] },
-                     @{ $spec{perlinc}  || [] } ) {
+  foreach my $path ( @{ %spec{includes} || [] },
+                     @{ %spec{perlinc}  || [] } ) {
     $path = '-I' . $path;
   }
 
   %spec = $self->write_compiler_script(%spec)
-    if $spec{use_scripts};
+    if %spec{use_scripts};
 
   return [ grep {defined && length} (
-    $spec{cc}, '-c'         ,
-    @{$spec{includes}}      ,
-    @{$spec{cflags}}        ,
-    @{$spec{optimize}}      ,
-    @{$spec{defines}}       ,
-    @{$spec{perlinc}}       ,
-    "-o$spec{output}"       ,
-    $spec{source}           ,
+    %spec{cc}, '-c'         ,
+    @{%spec{includes}}      ,
+    @{%spec{cflags}}        ,
+    @{%spec{optimize}}      ,
+    @{%spec{defines}}       ,
+    @{%spec{perlinc}}       ,
+    "-o%spec{output}"       ,
+    %spec{source}           ,
   ) ];
 }
 
 sub write_compiler_script {
   my ($self, %spec) = @_;
 
-  my $script = File::Spec->catfile( $spec{srcdir},
-                                    $spec{basename} . '.ccs' );
+  my $script = File::Spec->catfile( %spec{srcdir},
+                                    %spec{basename} . '.ccs' );
 
   $self->add_to_cleanup($script);
 
@@ -424,12 +424,12 @@ sub write_compiler_script {
     map { ref $_ ? @{$_} : $_ }
     grep defined,
     delete(
-      @spec{ qw(includes cflags optimize perlinc) } )
+      %spec{[qw(includes cflags optimize perlinc) ]} )
   );
 
   close SCRIPT;
 
-  push @{$spec{includes}}, '@"' . $script . '"';
+  push @{%spec{includes}}, '@"' . $script . '"';
 
   return %spec;
 }
@@ -437,28 +437,28 @@ sub write_compiler_script {
 sub format_linker_cmd {
   my ($self, %spec) = @_;
 
-  foreach my $path ( @{$spec{libpath}} ) {
+  foreach my $path ( @{%spec{libpath}} ) {
     $path = "-L$path";
   }
 
-  push( @{$spec{startup}}, 'c0d32.obj' )
-    unless ( $spec{starup} && @{$spec{startup}} );
+  push( @{%spec{startup}}, 'c0d32.obj' )
+    unless ( %spec{starup} && @{%spec{startup}} );
 
   %spec = $self->write_linker_script(%spec)
-    if $spec{use_scripts};
+    if %spec{use_scripts};
 
   return [ grep {defined && length} (
-    $spec{ld}               ,
-    @{$spec{lddlflags}}     ,
-    @{$spec{libpath}}       ,
-    @{$spec{other_ldflags}} ,
-    @{$spec{startup}}       ,
-    @{$spec{objects}}       , ',',
-    $spec{output}           , ',',
-    $spec{map_file}         , ',',
-    $spec{libperl}          ,
-    @{$spec{perllibs}}      , ',',
-    $spec{def_file}
+    %spec{ld}               ,
+    @{%spec{lddlflags}}     ,
+    @{%spec{libpath}}       ,
+    @{%spec{other_ldflags}} ,
+    @{%spec{startup}}       ,
+    @{%spec{objects}}       , ',',
+    %spec{output}           , ',',
+    %spec{map_file}         , ',',
+    %spec{libperl}          ,
+    @{%spec{perllibs}}      , ',',
+    %spec{def_file}
   ) ];
 }
 
@@ -468,10 +468,10 @@ sub write_linker_script {
   # To work around Borlands "unique" commandline syntax,
   # two scripts are used:
 
-  my $ld_script = File::Spec->catfile( $spec{srcdir},
-                                       $spec{basename} . '.lds' );
-  my $ld_libs   = File::Spec->catfile( $spec{srcdir},
-                                       $spec{basename} . '.lbs' );
+  my $ld_script = File::Spec->catfile( %spec{srcdir},
+                                       %spec{basename} . '.lds' );
+  my $ld_libs   = File::Spec->catfile( %spec{srcdir},
+                                       %spec{basename} . '.lbs' );
 
   $self->add_to_cleanup($ld_script, $ld_libs);
 
@@ -485,7 +485,7 @@ sub write_linker_script {
     map { @{$_} }
     grep defined,
     delete(
-      @spec{ qw(lddlflags libpath other_ldflags startup objects) } )
+      %spec{[qw(lddlflags libpath other_ldflags startup objects) ]} )
   );
 
   close LD_SCRIPT;
@@ -495,14 +495,14 @@ sub write_linker_script {
     or die( "Could not create linker script '$ld_libs': $!" );
 
   print LD_LIBS join( " +\n",
-     (delete $spec{libperl}  || ''),
-    @{delete $spec{perllibs} || []},
+     (delete %spec{libperl}  || ''),
+    @{delete %spec{perllibs} || []},
   );
 
   close LD_LIBS;
 
-  push @{$spec{lddlflags}}, '@"' . $ld_script  . '"';
-  push @{$spec{perllibs}},  '@"' . $ld_libs    . '"';
+  push @{%spec{lddlflags}}, '@"' . $ld_script  . '"';
+  push @{%spec{perllibs}},  '@"' . $ld_libs    . '"';
 
   return %spec;
 }
@@ -515,23 +515,23 @@ package ExtUtils::CBuilder::Platform::Windows::GCC;
 sub format_compiler_cmd {
   my ($self, %spec) = @_;
 
-  foreach my $path ( @{ $spec{includes} || [] },
-                     @{ $spec{perlinc}  || [] } ) {
+  foreach my $path ( @{ %spec{includes} || [] },
+                     @{ %spec{perlinc}  || [] } ) {
     $path = '-I' . $path;
   }
 
   # split off any -arguments included in cc
-  my @cc = split m/ (?=-)/, $spec{cc};
+  my @cc = split m/ (?=-)/, %spec{cc};
 
   return [ grep {defined && length} (
     @cc, '-c'               ,
-    @{$spec{includes}}      ,
-    @{$spec{cflags}}        ,
-    @{$spec{optimize}}      ,
-    @{$spec{defines}}       ,
-    @{$spec{perlinc}}       ,
-    '-o', $spec{output}     ,
-    $spec{source}           ,
+    @{%spec{includes}}      ,
+    @{%spec{cflags}}        ,
+    @{%spec{optimize}}      ,
+    @{%spec{defines}}       ,
+    @{%spec{perlinc}}       ,
+    '-o', %spec{output}     ,
+    %spec{source}           ,
   ) ];
 }
 
@@ -541,10 +541,10 @@ sub format_linker_cmd {
   # The Config.pm variable 'libperl' is hardcoded to the full name
   # of the perl import library (i.e. 'libperl56.a'). GCC will not
   # find it unless the 'lib' prefix & the extension are stripped.
-  $spec{libperl} =~ s/^(?:lib)?([^.]+).*$/-l$1/;
+  %spec{libperl} =~ s/^(?:lib)?([^.]+).*$/-l$1/;
 
-  unshift( @{$spec{other_ldflags}}, '-nostartfiles' )
-    if ( $spec{startup} && @{$spec{startup}} );
+  unshift( @{%spec{other_ldflags}}, '-nostartfiles' )
+    if ( %spec{startup} && @{%spec{startup}} );
 
   # From ExtUtils::MM_Win32:
   #
@@ -552,61 +552,61 @@ sub format_linker_cmd {
   ## we try to overcome non-relocateable-DLL problems by generating
   ##    a (hopefully unique) image-base from the dll's name
   ## -- BKS, 10-19-1999
-  File::Basename::basename( $spec{output} ) =~ m/(....)(.{0,4})/;
-  $spec{image_base} = sprintf( "0x%x0000", unpack('n', $1 ^^^ $2) );
+  File::Basename::basename( %spec{output} ) =~ m/(....)(.{0,4})/;
+  %spec{image_base} = sprintf( "0x\%x0000", unpack('n', $1 ^^^ $2) );
 
   %spec = $self->write_linker_script(%spec)
-    if $spec{use_scripts};
+    if %spec{use_scripts};
 
-  foreach my $path ( @{$spec{libpath}} ) {
+  foreach my $path ( @{%spec{libpath}} ) {
     $path = "-L$path";
   }
 
   my @cmds; # Stores the series of commands needed to build the module.
 
   push @cmds, [
-    'dlltool', '--def'        , $spec{def_file},
-               '--output-exp' , $spec{explib}
+    'dlltool', '--def'        , %spec{def_file},
+               '--output-exp' , %spec{explib}
   ];
 
   # split off any -arguments included in ld
-  my @ld = split m/ (?=-)/, $spec{ld};
+  my @ld = split m/ (?=-)/, %spec{ld};
 
   push @cmds, [ grep {defined && length} (
     @ld                       ,
-    '-o', $spec{output}       ,
-    "-Wl,--base-file,$spec{base_file}"   ,
-    "-Wl,--image-base,$spec{image_base}" ,
-    @{$spec{lddlflags}}       ,
-    @{$spec{libpath}}         ,
-    @{$spec{startup}}         ,
-    @{$spec{objects}}         ,
-    @{$spec{other_ldflags}}   ,
-    $spec{libperl}            ,
-    @{$spec{perllibs}}        ,
-    $spec{explib}             ,
-    $spec{map_file} ? ('-Map', $spec{map_file}) : ''
+    '-o', %spec{output}       ,
+    "-Wl,--base-file,%spec{base_file}"   ,
+    "-Wl,--image-base,%spec{image_base}" ,
+    @{%spec{lddlflags}}       ,
+    @{%spec{libpath}}         ,
+    @{%spec{startup}}         ,
+    @{%spec{objects}}         ,
+    @{%spec{other_ldflags}}   ,
+    %spec{libperl}            ,
+    @{%spec{perllibs}}        ,
+    %spec{explib}             ,
+    %spec{map_file} ? ('-Map', %spec{map_file}) : ''
   ) ];
 
   push @cmds, [
-    'dlltool', '--def'        , $spec{def_file},
-               '--output-exp' , $spec{explib},
-               '--base-file'  , $spec{base_file}
+    'dlltool', '--def'        , %spec{def_file},
+               '--output-exp' , %spec{explib},
+               '--base-file'  , %spec{base_file}
   ];
 
   push @cmds, [ grep {defined && length} (
     @ld                       ,
-    '-o', $spec{output}       ,
-    "-Wl,--image-base,$spec{image_base}" ,
-    @{$spec{lddlflags}}       ,
-    @{$spec{libpath}}         ,
-    @{$spec{startup}}         ,
-    @{$spec{objects}}         ,
-    @{$spec{other_ldflags}}   ,
-    $spec{libperl}            ,
-    @{$spec{perllibs}}        ,
-    $spec{explib}             ,
-    $spec{map_file} ? ('-Map', $spec{map_file}) : ''
+    '-o', %spec{output}       ,
+    "-Wl,--image-base,%spec{image_base}" ,
+    @{%spec{lddlflags}}       ,
+    @{%spec{libpath}}         ,
+    @{%spec{startup}}         ,
+    @{%spec{objects}}         ,
+    @{%spec{other_ldflags}}   ,
+    %spec{libperl}            ,
+    @{%spec{perllibs}}        ,
+    %spec{explib}             ,
+    %spec{map_file} ? ('-Map', %spec{map_file}) : ''
   ) ];
 
   return @cmds;
@@ -615,8 +615,8 @@ sub format_linker_cmd {
 sub write_linker_script {
   my ($self, %spec) = @_;
 
-  my $script = File::Spec->catfile( $spec{srcdir},
-                                    $spec{basename} . '.lds' );
+  my $script = File::Spec->catfile( %spec{srcdir},
+                                    %spec{basename} . '.lds' );
 
   $self->add_to_cleanup($script);
 
@@ -626,29 +626,29 @@ sub write_linker_script {
     or die( "Could not create script '$script': $!" );
 
   print( SCRIPT 'SEARCH_DIR(' . $_ . ")\n" )
-    for @{delete $spec{libpath} || []};
+    for @{delete %spec{libpath} || []};
 
   # gcc takes only one startup file, so the first object in startup is
   # specified as the startup file and any others are shifted into the
   # beginning of the list of objects.
-  if ( $spec{startup} && @{$spec{startup}} ) {
-    print SCRIPT 'STARTUP(' . shift( @{$spec{startup}} ) . ")\n";
-    unshift @{$spec{objects}},
-      @{delete $spec{startup} || []};
+  if ( %spec{startup} && @{%spec{startup}} ) {
+    print SCRIPT 'STARTUP(' . shift( @{%spec{startup}} ) . ")\n";
+    unshift @{%spec{objects}},
+      @{delete %spec{startup} || []};
   }
 
   print SCRIPT 'INPUT(' . join( ',',
-    @{delete $spec{objects}  || []}
+    @{delete %spec{objects}  || []}
   ) . ")\n";
 
   print SCRIPT 'INPUT(' . join( ' ',
-     (delete $spec{libperl}  || ''),
-    @{delete $spec{perllibs} || []},
+     (delete %spec{libperl}  || ''),
+    @{delete %spec{perllibs} || []},
   ) . ")\n";
 
   close SCRIPT;
 
-  push @{$spec{other_ldflags}}, '"' . $script . '"';
+  push @{%spec{other_ldflags}}, '"' . $script . '"';
 
   return %spec;
 }
