@@ -20,24 +20,24 @@ our @ISA = qw(ExtUtils::MM_Any);
 
 my %Is;
 BEGIN { 
-    $Is{OS2}     = $^O eq 'os2';
-    $Is{Win32}   = $^O eq 'MSWin32' || $Config{osname} eq 'NetWare';
-    $Is{Dos}     = $^O eq 'dos';
-    $Is{VMS}     = $^O eq 'VMS';
-    $Is{OSF}     = $^O eq 'dec_osf';
-    $Is{IRIX}    = $^O eq 'irix';
-    $Is{NetBSD}  = $^O eq 'netbsd';
-    $Is{Interix} = $^O eq 'interix';
-    $Is{SunOS4}  = $^O eq 'sunos';
-    $Is{Solaris} = $^O eq 'solaris';
-    $Is{SunOS}   = $Is{SunOS4} || $Is{Solaris};
-    $Is{BSD}     = ($^O =~ m/^(?:free|net|open)bsd$/ or
+    %Is{OS2}     = $^O eq 'os2';
+    %Is{Win32}   = $^O eq 'MSWin32' || %Config{osname} eq 'NetWare';
+    %Is{Dos}     = $^O eq 'dos';
+    %Is{VMS}     = $^O eq 'VMS';
+    %Is{OSF}     = $^O eq 'dec_osf';
+    %Is{IRIX}    = $^O eq 'irix';
+    %Is{NetBSD}  = $^O eq 'netbsd';
+    %Is{Interix} = $^O eq 'interix';
+    %Is{SunOS4}  = $^O eq 'sunos';
+    %Is{Solaris} = $^O eq 'solaris';
+    %Is{SunOS}   = %Is{SunOS4} || %Is{Solaris};
+    %Is{BSD}     = ($^O =~ m/^(?:free|net|open)bsd$/ or
                    grep( $^O eq $_, qw(bsdos interix dragonfly) )
                   );
 }
 
 BEGIN {
-    if( $Is{VMS} ) {
+    if( %Is{VMS} ) {
         # For things like vmsify()
         require VMS::Filespec;
         VMS::Filespec->import;
@@ -130,7 +130,7 @@ sub c_o {
     my $command = '$(CCCMD)';
     my $flags   = '$(CCCDLFLAGS) "-I$(PERL_INC)" $(PASTHRU_DEFINE) $(DEFINE)';
     
-    if (my $cpp = $Config{cpprun}) {
+    if (my $cpp = %Config{cpprun}) {
         my $cpp_cmd = $self->const_cccmd;
         $cpp_cmd =~ s/^CCCMD\s*=\s*\$\(CC\)/$cpp/;
         push @m, qq{
@@ -159,7 +159,7 @@ sub c_o {
     push @m, qq{
 .C\$(OBJ_EXT):
 	$command \$*.C
-} if !$Is{OS2} and !$Is{Win32} and !$Is{Dos}; #Case-specific
+} if !%Is{OS2} and !%Is{Win32} and !%Is{Dos}; #Case-specific
 
     return join "", @m;
 }
@@ -184,11 +184,11 @@ sub cflags {
     $libperl ||= $self->{LIBPERL_A} || "libperl$self->{LIB_EXT}" ;
     $libperl =~ s/\.\$\(A\)$/$self->{LIB_EXT}/;
 
-    @cflags{qw(cc ccflags optimize shellflags)}
-	= @Config{qw(cc ccflags optimize shellflags)};
+    %cflags{[qw(cc ccflags optimize shellflags)]}
+	= %Config{[qw(cc ccflags optimize shellflags)]};
     my($optdebug) = "";
 
-    $cflags{shellflags} ||= '';
+    %cflags{shellflags} ||= '';
 
     my(%map) =  (
 		D =>   '-DDEBUGGING',
@@ -203,7 +203,7 @@ sub cflags {
     } else {
 	$uc = ""; # avoid warning
     }
-    $perltype = $map{$uc} ? $map{$uc} : "";
+    $perltype = %map{$uc} ? %map{$uc} : "";
 
     if ($uc =~ m/^D/) {
 	$optdebug = "-g";
@@ -212,14 +212,14 @@ sub cflags {
 
     my($name);
     ( $name = $self->{NAME} . "_cflags" ) =~ s/:/_/g ;
-    if ($prog = $Config{$name}) {
+    if ($prog = %Config{$name}) {
 	# Expand hints for this extension via the shell
 	print STDOUT "Processing $name hint:\n" if $Verbose;
-	my(@o)=`cc=\"$cflags{cc}\"
-	  ccflags=\"$cflags{ccflags}\"
-	  optimize=\"$cflags{optimize}\"
-	  perltype=\"$cflags{perltype}\"
-	  optdebug=\"$cflags{optdebug}\"
+	my(@o)=`cc=\"%cflags{cc}\"
+	  ccflags=\"%cflags{ccflags}\"
+	  optimize=\"%cflags{optimize}\"
+	  perltype=\"%cflags{perltype}\"
+	  optdebug=\"%cflags{optdebug}\"
 	  eval '$prog'
 	  echo cc=\$cc
 	  echo ccflags=\$ccflags
@@ -230,7 +230,7 @@ sub cflags {
 	foreach my $line (@o){
 	    chomp $line;
 	    if ($line =~ m/(.*?)=\s*(.*)\s*$/){
-		$cflags{$1} = $2;
+		%cflags{$1} = $2;
 		print STDOUT "	$1 = $2\n" if $Verbose;
 	    } else {
 		print STDOUT "Unrecognised result from hint: '$line'\n";
@@ -239,15 +239,15 @@ sub cflags {
     }
 
     if ($optdebug) {
-	$cflags{optimize} = $optdebug;
+	%cflags{optimize} = $optdebug;
     }
 
     for (qw(ccflags optimize perltype)) {
-        $cflags{$_} ||= '';
-	$cflags{$_} =~ s/^\s+//;
-	$cflags{$_} =~ s/\s+/ /g;
-	$cflags{$_} =~ s/\s+$//;
-	$self->{uc $_} ||= $cflags{$_};
+        %cflags{$_} ||= '';
+	%cflags{$_} =~ s/^\s+//;
+	%cflags{$_} =~ s/\s+/ /g;
+	%cflags{$_} =~ s/\s+$//;
+	$self->{uc $_} ||= %cflags{$_};
     }
 
     if ($self->{POLLUTE}) {
@@ -255,8 +255,8 @@ sub cflags {
     }
 
     my $pollute = '';
-    if ($Config{usemymalloc} and not $Config{bincompat5005}
-	and not $Config{ccflags} =~ m/-DPERL_POLLUTE_MALLOC\b/
+    if (%Config{usemymalloc} and not %Config{bincompat5005}
+	and not %Config{ccflags} =~ m/-DPERL_POLLUTE_MALLOC\b/
 	and $self->{PERL_MALLOC_OK}) {
 	$pollute = '$(PERL_MALLOC_DEF)';
     }
@@ -305,17 +305,17 @@ sub const_config {
     my($self) = shift;
     my @m = <<"END";
 
-# These definitions are from config.sh (via $INC{'Config.pm'}).
+# These definitions are from config.sh (via %INC{'Config.pm'}).
 # They may have been overridden via Makefile.PL or on the command line.
 END
 
     my(%once_only);
     foreach my $key (@{$self->{CONFIG}}){
         # SITE*EXP macros are defined in &constants; avoid duplicates here
-        next if $once_only{$key};
+        next if %once_only{$key};
         $self->{uc $key} = quote_paren($self->{uc $key});
         push @m, uc($key) , ' = ' , $self->{uc $key}, "\n";
-        $once_only{$key} = 1;
+        %once_only{$key} = 1;
     }
     join('', @m);
 }
@@ -605,7 +605,7 @@ sub dist {
             DISTNAME DISTVNAME
            ))
     {
-        my $value = $attribs{$key} || $self->{$key};
+        my $value = %attribs{$key} || $self->{$key};
         $make .= "$key = $value\n";
     }
 
@@ -855,7 +855,7 @@ sub dynamic_bs {
 BOOTSTRAP =
 ' unless $self->has_link_code();
 
-    my $target = $Is{VMS} ? '$(MMS$TARGET)' : '$@';
+    my $target = %Is{VMS} ? '$(MMS$TARGET)' : '$@';
 
     return sprintf <<'MAKE_FRAG', ($target) x 5;
 BOOTSTRAP = $(BASEEXT).bs
@@ -890,14 +890,14 @@ sub dynamic_lib {
 
     return '' unless $self->has_link_code;
 
-    my($otherldflags) = $attribs{OTHERLDFLAGS} || "";
-    my($inst_dynamic_dep) = $attribs{INST_DYNAMIC_DEP} || "";
-    my($armaybe) = $attribs{ARMAYBE} || $self->{ARMAYBE} || ":";
+    my($otherldflags) = %attribs{OTHERLDFLAGS} || "";
+    my($inst_dynamic_dep) = %attribs{INST_DYNAMIC_DEP} || "";
+    my($armaybe) = %attribs{ARMAYBE} || $self->{ARMAYBE} || ":";
     my($ldfrom) = '$(LDFROM)';
-    $armaybe = 'ar' if ($Is{OSF} and $armaybe eq ':');
+    $armaybe = 'ar' if (%Is{OSF} and $armaybe eq ':');
     my(@m);
-    my $ld_opt = $Is{OS2} ? '$(OPTIMIZE) ' : '';	# Useful on other systems too?
-    my $ld_fix = $Is{OS2} ? '|| ( $(RM_F) $@ && sh -c false )' : '';
+    my $ld_opt = %Is{OS2} ? '$(OPTIMIZE) ' : '';	# Useful on other systems too?
+    my $ld_fix = %Is{OS2} ? '|| ( $(RM_F) $@ && sh -c false )' : '';
     push(@m,'
 # This section creates the dynamically loadable $(INST_DYNAMIC)
 # from $(OBJECT) and possibly $(MYEXTLIB).
@@ -913,10 +913,10 @@ $(INST_DYNAMIC): $(OBJECT) $(MYEXTLIB) $(BOOTSTRAP) $(INST_ARCHAUTODIR)$(DFSEP).
 	push(@m,'	$(ARMAYBE) cr '.$ldfrom.' $(OBJECT)'."\n");
 	push(@m,'	$(RANLIB) '."$ldfrom\n");
     }
-    $ldfrom = "-all $ldfrom -none" if $Is{OSF};
+    $ldfrom = "-all $ldfrom -none" if %Is{OSF};
 
     # The IRIX linker doesn't use LD_RUN_PATH
-    my $ldrun = $Is{IRIX} && $self->{LD_RUN_PATH} ?         
+    my $ldrun = %Is{IRIX} && $self->{LD_RUN_PATH} ?         
                        qq{-rpath "$self->{LD_RUN_PATH}"} : '';
 
     # For example in AIX the shared objects/libraries from previous builds
@@ -929,14 +929,14 @@ $(INST_DYNAMIC): $(OBJECT) $(MYEXTLIB) $(BOOTSTRAP) $(INST_ARCHAUTODIR)$(DFSEP).
 
     my $libs = '$(LDLOADLIBS)';
 
-    if (($Is{NetBSD} || $Is{Interix}) && $Config{'useshrplib'} eq 'true') {
+    if ((%Is{NetBSD} || %Is{Interix}) && %Config{'useshrplib'} eq 'true') {
 	# Use nothing on static perl platforms, and to the flags needed
 	# to link against the shared libperl library on shared perl
 	# platforms.  We peek at lddlflags to see if we need -Wl,-R
 	# or -R to add paths to the run-time library search path.
-        if ($Config{'lddlflags'} =~ m/-Wl,-R/) {
+        if (%Config{'lddlflags'} =~ m/-Wl,-R/) {
             $libs .= ' -L$(PERL_INC) -Wl,-R$(INSTALLARCHLIB)/CORE -Wl,-R$(PERL_ARCHLIB)/CORE -lperl';
-        } elsif ($Config{'lddlflags'} =~ m/-R/) {
+        } elsif (%Config{'lddlflags'} =~ m/-R/) {
             $libs .= ' -L$(PERL_INC) -R$(INSTALLARCHLIB)/CORE -R$(PERL_ARCHLIB)/CORE -lperl';
         }
     }
@@ -1002,7 +1002,7 @@ in these dirs:
 
     my $stderr_duped = 0;
     my $stderr_copy;
-    unless ($Is{BSD}) {
+    unless (%Is{BSD}) {
         if( open($stderr_copy, '>&', \*STDERR) ) {
             $stderr_duped = 1;
         }
@@ -1031,8 +1031,8 @@ WARNING
             print "Executing $abs\n" if ($trace +>= 2);
 
             my $version_check = qq{$abs -le "\$^V =~ m/^\Q$ver\E/; print qq\{VER_OK\}"};
-            $version_check = "$Config{run} $version_check"
-                if defined $Config{run} and length $Config{run};
+            $version_check = "%Config{run} $version_check"
+                if defined %Config{run} and length %Config{run};
 
             # To avoid using the unportable 2>&1 to suppress STDERR,
             # we close it before running the command.
@@ -1040,7 +1040,7 @@ WARNING
             # ( http://www.freebsd.org/cgi/query-pr.cgi?pr=51535 )
             # we cannot use the fancier more portable way in here
             # but instead need to use the traditional 2>&1 construct.
-            if ($Is{BSD}) {
+            if (%Is{BSD}) {
                 $val = `$version_check 2>&1`;
             } else {
                 close STDERR if $stderr_duped;
@@ -1072,7 +1072,7 @@ Inserts the sharpbang or equivalent magic number to a set of @files.
 sub fixin {    # stolen from the pink Camel book, more or less
     my ( $self, @files ) = @_;
 
-    my ($does_shbang) = $Config{'sharpbang'} =~ m/^\s*\#\!/;
+    my ($does_shbang) = %Config{'sharpbang'} =~ m/^\s*\#\!/;
     for my $file (@files) {
         my $file_new = "$file.new";
         my $file_bak = "$file.bak";
@@ -1088,12 +1088,12 @@ sub fixin {    # stolen from the pink Camel book, more or less
         # Now look (in reverse) for interpreter in absolute PATH (unless perl).
         my $interpreter;
         if ( $cmd eq "perl" ) {
-            if ( $Config{startperl} =~ m,^\#!.*/perl, ) {
-                $interpreter = $Config{startperl};
+            if ( %Config{startperl} =~ m,^\#!.*/perl, ) {
+                $interpreter = %Config{startperl};
                 $interpreter =~ s,^\#!,,;
             }
             else {
-                $interpreter = $Config{perlpath};
+                $interpreter = %Config{perlpath};
             }
         }
         else {
@@ -1119,14 +1119,14 @@ sub fixin {    # stolen from the pink Camel book, more or less
 
             # this is probably value-free on DOSISH platforms
             if ($does_shbang) {
-                $shb .= "$Config{'sharpbang'}$interpreter";
+                $shb .= "%Config{'sharpbang'}$interpreter";
                 $shb .= ' ' . $arg if defined $arg;
                 $shb .= "\n";
             }
             $shb .= qq{
 eval 'exec $interpreter $arg -S \$0 \$\{1+"\$\@"\}'
     if 0; # not running under some shell
-} unless $Is{Win32};    # this won't work on win32, so don't
+} unless %Is{Win32};    # this won't work on win32, so don't
         }
         else {
             warn "Can't find $cmd in PATH, $file unchanged"
@@ -1163,7 +1163,7 @@ eval 'exec $interpreter $arg -S \$0 \$\{1+"\$\@"\}'
         unlink $file_bak;
     }
     continue {
-        system("$Config{'eunicefix'} $file") if $Config{'eunicefix'} ne ':';
+        system("%Config{'eunicefix'} $file") if %Config{'eunicefix'} ne ':';
     }
 }
 
@@ -1172,7 +1172,7 @@ sub _rename {
     my($old, $new) = @_;
 
     foreach my $file ($old, $new) {
-        if( $Is{VMS} and basename($file) !~ m/\./ ) {
+        if( %Is{VMS} and basename($file) !~ m/\./ ) {
             # rename() in 5.8.0 on VMS will not rename a file if it
             # does not contain a dot yet it returns success.
             $file = "$file.";
@@ -1253,42 +1253,42 @@ sub init_dirscan {	# --- File and Directory Lists (.xs .pm .pod etc)
     my %ignore = map {( $_ => 1 )} qw(Makefile.PL Build.PL test.pl t);
 
     # ignore the distdir
-    $Is{VMS} ? $ignore{"$self->{DISTVNAME}.dir"} = 1
-            : $ignore{$self->{DISTVNAME}} = 1;
+    %Is{VMS} ? %ignore{"$self->{DISTVNAME}.dir"} = 1
+            : %ignore{$self->{DISTVNAME}} = 1;
 
-    @ignore{map lc, keys %ignore} = values %ignore if $Is{VMS};
+    %ignore{[map lc, keys %ignore]} = values %ignore if %Is{VMS};
 
     foreach my $name ($self->lsdir($Curdir)){
 	next if $name =~ m/\#/;
-	next if $name eq $Curdir or $name eq $Updir or $ignore{$name};
+	next if $name eq $Curdir or $name eq $Updir or %ignore{$name};
 	next unless $self->libscan($name);
 	if (-d $name){
 	    next if -l $name; # We do not support symlinks at all
             next if $self->{NORECURS};
-	    $dir{$name} = $name if (-f $self->catfile($name,"Makefile.PL"));
+	    %dir{$name} = $name if (-f $self->catfile($name,"Makefile.PL"));
 	} elsif ($name =~ m/\.xs\z/){
 	    my($c); ($c = $name) =~ s/\.xs\z/.c/;
-	    $xs{$name} = $c;
-	    $c{$c} = 1;
+	    %xs{$name} = $c;
+	    %c{$c} = 1;
 	} elsif ($name =~ m/\.c(pp|xx|c)?\z/i){  # .c .C .cpp .cxx .cc
-	    $c{$name} = 1
+	    %c{$name} = 1
 		unless $name =~ m/perlmain\.c/; # See MAP_TARGET
 	} elsif ($name =~ m/\.h\z/i){
-	    $h{$name} = 1;
+	    %h{$name} = 1;
 	} elsif ($name =~ m/\.PL\z/) {
-	    ($pl_files{$name} = $name) =~ s/\.PL\z// ;
-	} elsif (($Is{VMS} || $Is{Dos}) && $name =~ m/[._]pl$/i) {
+	    (%pl_files{$name} = $name) =~ s/\.PL\z// ;
+	} elsif ((%Is{VMS} || %Is{Dos}) && $name =~ m/[._]pl$/i) {
 	    # case-insensitive filesystem, one dot per name, so foo.h.PL
 	    # under Unix appears as foo.h_pl under VMS or fooh.pl on Dos
 	    local($/); open(my $pl, '<', $name); my $txt = ~< $pl; close $pl;
 	    if ($txt =~ m/Extracting \S+ \(with variable substitutions/) {
-		($pl_files{$name} = $name) =~ s/[._]pl\z//i ;
+		(%pl_files{$name} = $name) =~ s/[._]pl\z//i ;
 	    }
 	    else { 
-                $pm{$name} = $self->catfile($self->{INST_LIBDIR},$name); 
+                %pm{$name} = $self->catfile($self->{INST_LIBDIR},$name); 
             }
 	} elsif ($name =~ m/\.(p[ml]|pod)\z/){
-	    $pm{$name} = $self->catfile($self->{INST_LIBDIR},$name);
+	    %pm{$name} = $self->catfile($self->{INST_LIBDIR},$name);
 	}
     }
 
@@ -1316,13 +1316,13 @@ sub init_MANPODS {
 
     # Set up names of manual pages to generate from pods
     foreach my $man (qw(MAN1 MAN3)) {
-	if ( $self->{"${man}PODS"}
-             or $self->{"INSTALL${man}DIR"} =~ m/^(none|\s*)$/
+	if ( $self->{"{$man}PODS"}
+             or $self->{"INSTALL{$man}DIR"} =~ m/^(none|\s*)$/
         ) {
-            $self->{"${man}PODS"} ||= {};
+            $self->{"{$man}PODS"} ||= {};
         }
         else {
-            my $init_method = "init_${man}PODS";
+            my $init_method = "init_{$man}PODS";
             $self->?$init_method();
 	}
     }
@@ -1385,10 +1385,10 @@ sub init_MAN3PODS {
 
     foreach my $name (keys %{$self->{PM}}) {
 	if ($name =~ m/\.pod\z/ ) {
-	    $manifypods{$name} = $self->{PM}{$name};
+	    %manifypods{$name} = $self->{PM}{$name};
 	} elsif ($name =~ m/\.p[ml]\z/ ) {
 	    if( $self->_has_pod($name) ) {
-		$manifypods{$name} = $self->{PM}{$name};
+		%manifypods{$name} = $self->{PM}{$name};
 	    }
 	}
     }
@@ -1400,7 +1400,7 @@ sub init_MAN3PODS {
     # MAN3PODS
     foreach my $name (keys %manifypods) {
 	if ($self->{PERL_CORE} and $name =~ m/(config|setup).*\.pm/is) {
-	    delete $manifypods{$name};
+	    delete %manifypods{$name};
 	    next;
 	}
 	my($manpagename) = $name;
@@ -1454,7 +1454,7 @@ sub init_PM {
     # that's important for nested modules.
 
     unless( $self->{PMLIBDIRS} ) {
-        if( $Is{VMS} ) {
+        if( %Is{VMS} ) {
             # Avoid logical name vs directory collisions
             $self->{PMLIBDIRS} = ['./lib', "./$self->{BASEEXT}"];
         }
@@ -1471,7 +1471,7 @@ sub init_PM {
     @{$self->{PMLIBDIRS}} = ();
     my %dir = map { ($_ => $_) } @{$self->{DIR}};
     foreach my $pmlibdir (@pmlibdirs) {
-	-d $pmlibdir && !$dir{$pmlibdir} && push @{$self->{PMLIBDIRS}}, $pmlibdir;
+	-d $pmlibdir && !%dir{$pmlibdir} && push @{$self->{PMLIBDIRS}}, $pmlibdir;
     }
 
     unless( $self->{PMLIBPARENTDIRS} ) {
@@ -1557,7 +1557,7 @@ sub init_main {
     # Copied from DynaLoader:
 
     my(@modparts) = split(m/::/,$self->{NAME});
-    my($modfname) = $modparts[-1];
+    my($modfname) = @modparts[-1];
 
     # Some systems have restrictions on files names for DLL's etc.
     # mod2fname returns appropriate file base name (typically truncated)
@@ -1580,7 +1580,7 @@ sub init_main {
     # --- Initialize PERL_LIB, PERL_SRC
 
     # *Real* information: where did we get these two from? ...
-    my $inc_config_dir = dirname($INC{'Config.pm'});
+    my $inc_config_dir = dirname(%INC{'Config.pm'});
 
     unless ($self->{PERL_SRC}){
         foreach my $dir_count (1..8) { # 8 is the VMS limit for nesting
@@ -1607,11 +1607,11 @@ sub init_main {
               $self->catdir("$self->{PERL_SRC}","xlib",$Cross::platform);
             $self->{PERL_INC}     = 
               $self->catdir("$self->{PERL_SRC}","xlib",$Cross::platform, 
-                                 $Is{Win32}?("CORE"):());
+                                 %Is{Win32}?("CORE"):());
         }
         else {
             $self->{PERL_ARCHLIB} = $self->{PERL_LIB};
-            $self->{PERL_INC}     = ($Is{Win32}) ? 
+            $self->{PERL_INC}     = (%Is{Win32}) ? 
               $self->catdir($self->{PERL_LIB},"CORE") : $self->{PERL_SRC};
         }
 
@@ -1619,11 +1619,11 @@ sub init_main {
 	unless (
 		-s $self->catfile($self->{PERL_SRC},'cflags')
 		or
-		$Is{VMS}
+		%Is{VMS}
 		&&
 		-s $self->catfile($self->{PERL_SRC},'perlshr_attr.opt')
 		or
-		$Is{Win32}
+		%Is{Win32}
 	       ){
 	    warn qq{
 You cannot build extensions below the perl source tree after executing
@@ -1642,8 +1642,8 @@ from the perl source tree.
     } else {
 	# we should also consider $ENV{PERL5LIB} here
         my $old = $self->{PERL_LIB} || $self->{PERL_ARCHLIB} || $self->{PERL_INC};
-	$self->{PERL_LIB}     ||= $Config{privlibexp};
-	$self->{PERL_ARCHLIB} ||= $Config{archlibexp};
+	$self->{PERL_LIB}     ||= %Config{privlibexp};
+	$self->{PERL_ARCHLIB} ||= %Config{archlibexp};
 	$self->{PERL_INC}     = $self->catdir("$self->{PERL_ARCHLIB}","CORE"); # wild guess for now
 	my $perl_h;
 
@@ -1658,7 +1658,7 @@ from the perl source tree.
 	    if ($lib) {
               # Win32 puts its header files in /perl/src/lib/CORE.
               # Unix leaves them in /perl/src.
-	      my $inc = $Is{Win32} ? $self->catdir($lib, "CORE" )
+	      my $inc = %Is{Win32} ? $self->catdir($lib, "CORE" )
                                   : dirname $lib;
 	      if (-e $self->catdir($inc, "perl.h")) {
 		$self->{PERL_LIB}	   = $lib;
@@ -1680,22 +1680,22 @@ EOP
     # MakeMaker.
     $self->{INSTALLDIRS} ||= "site";
 
-    $self->{MAN1EXT} ||= $Config{man1ext};
-    $self->{MAN3EXT} ||= $Config{man3ext};
+    $self->{MAN1EXT} ||= %Config{man1ext};
+    $self->{MAN3EXT} ||= %Config{man3ext};
 
     # Get some stuff out of %Config if we haven't yet done so
     print STDOUT "CONFIG must be an array ref\n"
         if ($self->{CONFIG} and ref $self->{CONFIG} ne 'ARRAY');
     $self->{CONFIG} = [] unless (ref $self->{CONFIG});
     push(@{$self->{CONFIG}}, @ExtUtils::MakeMaker::Get_from_Config);
-    push(@{$self->{CONFIG}}, 'shellflags') if $Config{shellflags};
+    push(@{$self->{CONFIG}}, 'shellflags') if %Config{shellflags};
     my(%once_only);
     foreach my $m (@{$self->{CONFIG}}){
-        next if $once_only{$m};
+        next if %once_only{$m};
         print STDOUT "CONFIG key '$m' does not exist in Config.pm\n"
-                unless exists $Config{$m};
-        $self->{uc $m} ||= $Config{$m};
-        $once_only{$m} = 1;
+                unless exists %Config{$m};
+        $self->{uc $m} ||= %Config{$m};
+        %once_only{$m} = 1;
     }
 
 # This is too dangerous:
@@ -1749,7 +1749,7 @@ sub init_others {	# --- Initialize Other Attributes
     foreach my $libs ( @{$self->{LIBS}} ){
 	$libs =~ s/^\s*(.*\S)\s*$/$1/; # remove leading and trailing whitespace
 	my(@libs) = $self->extliblist($libs);
-	if ($libs[0] or $libs[1] or $libs[2]){
+	if (@libs[0] or @libs[1] or @libs[2]){
 	    # LD_RUN_PATH now computed by ExtUtils::Liblist
 	    ($self->{EXTRALIBS},  $self->{BSLOADLIBS}, 
              $self->{LDLOADLIBS}, $self->{LD_RUN_PATH}) = @libs;
@@ -1776,7 +1776,7 @@ sub init_others {	# --- Initialize Other Attributes
     if (!$self->{LINKTYPE}) {
        $self->{LINKTYPE} = $self->{SKIPHASH}{'dynamic'}
                         ? 'static'
-                        : ($Config{usedl} ? 'dynamic' : 'static');
+                        : (%Config{usedl} ? 'dynamic' : 'static');
     };
 
     $self->{NOOP}               ||= '$(SHELL) -c true';
@@ -1795,7 +1795,7 @@ sub init_others {	# --- Initialize Other Attributes
     # Not everybody uses -f to indicate "use this Makefile instead"
     $self->{USEMAKEFILE}        ||= '-f';
 
-    $self->{SHELL}              ||= $Config{sh} || '/bin/sh';
+    $self->{SHELL}              ||= %Config{sh} || '/bin/sh';
 
     $self->{ECHO}       ||= 'echo';
     $self->{ECHO_N}     ||= 'echo -n';
@@ -1874,7 +1874,7 @@ sub init_lib2arch {
         my $Lib = uc $lib;
         my $Arch = uc "install$libpair->{a}";
         if( $self->{$Lib} && ! $self->{$Arch} ){
-            my($ilib) = $Config{$lib};
+            my($ilib) = %Config{$lib};
 
             $self->prefixify($Arch,$ilib,$self->{$Lib});
 
@@ -1914,28 +1914,28 @@ sub init_PERL {
 
     my @defpath = ();
     foreach my $component ($self->{PERL_SRC}, $self->path(), 
-                           $Config{binexp}) 
+                           %Config{binexp}) 
     {
 	push @defpath, $component if defined $component;
     }
 
     # Build up a set of file names (not command names).
     my $thisperl = $self->canonpath($^X);
-    $thisperl .= $Config{exe_ext} unless 
+    $thisperl .= %Config{exe_ext} unless 
                 # VMS might have a file version # at the end
-      $Is{VMS} ? $thisperl =~ m/$Config{exe_ext}(;\d+)?$/i
-              : $thisperl =~ m/$Config{exe_ext}$/i;
+      %Is{VMS} ? $thisperl =~ m/%Config{exe_ext}(;\d+)?$/i
+              : $thisperl =~ m/%Config{exe_ext}$/i;
 
     # We need a relative path to perl when in the core.
     $thisperl = $self->abs2rel($thisperl) if $self->{PERL_CORE};
 
     my @perls = ($thisperl);
-    push @perls, map { "$_$Config{exe_ext}" }
-                     ('perl', 'perl5', "perl$Config{version}");
+    push @perls, map { "$_%Config{exe_ext}" }
+                     ('perl', 'perl5', "perl%Config{version}");
 
     # miniperl has priority over all but the cannonical perl when in the
     # core.  Otherwise its a last resort.
-    my $miniperl = "miniperl$Config{exe_ext}";
+    my $miniperl = "miniperl%Config{exe_ext}";
     if( $self->{PERL_CORE} ) {
         splice @perls, 1, 0, $miniperl;
     }
@@ -1950,8 +1950,8 @@ sub init_PERL {
 
     # When built for debugging, VMS doesn't create perl.exe but ndbgperl.exe.
     my $perl_name = 'perl';
-    $perl_name = 'ndbgperl' if $Is{VMS} && 
-      defined $Config{usevmsdebug} && $Config{usevmsdebug} eq 'define';
+    $perl_name = 'ndbgperl' if %Is{VMS} && 
+      defined %Config{usevmsdebug} && %Config{usevmsdebug} eq 'define';
 
     # XXX This logic is flawed.  If "miniperl" is anywhere in the path
     # it will get confused.  It should be fixed to work only on the filename.
@@ -1975,7 +1975,7 @@ sub init_PERL {
         if ($self->{ABSPERL} =~ m/\s/) && ! $has_mcr;
 
     # Are we building the core?
-    $self->{PERL_CORE} = $ENV{PERL_CORE} unless exists $self->{PERL_CORE};
+    $self->{PERL_CORE} = %ENV{PERL_CORE} unless exists $self->{PERL_CORE};
     $self->{PERL_CORE} = 0               unless defined $self->{PERL_CORE};
 
     # How do we run perl?
@@ -2210,7 +2210,7 @@ sub installbin {
     my @exefiles = @{$self->{EXE_FILES}};
     return "" unless @exefiles;
 
-    @exefiles = map vmsify($_), @exefiles if $Is{VMS};
+    @exefiles = map vmsify($_), @exefiles if %Is{VMS};
 
     my %fromto;
     for my $from (@exefiles) {
@@ -2220,8 +2220,8 @@ sub installbin {
 	my $to = $self->libscan($path);
 	print "libscan($from) => '$to'\n" if ($Verbose +>=2);
 
-        $to = vmsify($to) if $Is{VMS};
-	$fromto{$from} = $to;
+        $to = vmsify($to) if %Is{VMS};
+	%fromto{$from} = $to;
     }
     my @to   = values %fromto;
 
@@ -2268,8 +2268,8 @@ Defines the linkext target which in turn defines the LINKTYPE.
 sub linkext {
     my($self, %attribs) = @_;
     # LINKTYPE => static or dynamic or ''
-    my($linktype) = defined $attribs{LINKTYPE} ?
-      $attribs{LINKTYPE} : '$(LINKTYPE)';
+    my($linktype) = defined %attribs{LINKTYPE} ?
+      %attribs{LINKTYPE} : '$(LINKTYPE)';
     "
 linkext :: $linktype
 	\$(NOECHO) \$(NOOP)
@@ -2326,7 +2326,7 @@ DynaLoader_pure_p1_c0_032.a are automatically ignored to avoid link errors.)
 sub makeaperl {
     my($self, %attribs) = @_;
     my($makefilename, $searchdirs, $static, $extra, $perlinc, $target, $tmp, $libperl) =
-	@attribs{qw(MAKE DIRS STAT EXTRA INCL TARGET TMP LIBPERL)};
+	%attribs{[qw(MAKE DIRS STAT EXTRA INCL TARGET TMP LIBPERL)]};
     my(@m);
     push @m, "
 # --- MakeMaker makeaperl section ---
@@ -2369,13 +2369,13 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
     $cccmd = $self->const_cccmd($libperl);
     $cccmd =~ s/^CCCMD\s*=\s*//;
     $cccmd =~ s/\$\(INC\)/ "-I$self->{PERL_INC}" /;
-    $cccmd .= " $Config{cccdlflags}"
-	if ($Config{useshrplib} eq 'true');
+    $cccmd .= " %Config{cccdlflags}"
+	if (%Config{useshrplib} eq 'true');
     $cccmd =~ s/\(CC\)/\(PERLMAINCC\)/;
 
     # The front matter of the linkcommand...
     $linkcmd = join ' ', "\$(CC)",
-	    grep($_, @Config{qw(ldflags ccdlflags)});
+	    grep($_, %Config{[qw(ldflags ccdlflags)]});
     $linkcmd =~ s/\s+/ /g;
     $linkcmd =~ s,(perl\.exp),\$(PERL_INC)/$1,;
 
@@ -2429,12 +2429,12 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 	# drop it
 	return if $File::Find::name =~ m:auto/$self->{FULLEXT}/$self->{BASEEXT}$self->{LIB_EXT}\z:;
 	use Cwd 'cwd';
-	$static{cwd() . "/" . $_}++;
+	%static{cwd() . "/" . $_}++;
     }, grep( -d $_, @{$searchdirs || []}) );
 
     # We trust that what has been handed in as argument, will be buildable
     $static = [] unless $static;
-    @static{@{$static}} = (1) x @{$static};
+    %static{[@{$static}]} = (1) x @{$static};
 
     $extra = [] unless $extra && ref $extra eq 'ARRAY';
     for (sort keys %static) {
@@ -2457,7 +2457,7 @@ MAP_PERLINC   = @{$perlinc || []}
 MAP_STATIC    = ",
 join(" \\\n\t", reverse sort keys %static), "
 
-MAP_PRELIBS   = $Config{perllibs} $Config{cryptlib}
+MAP_PRELIBS   = %Config{perllibs} %Config{cryptlib}
 ";
 
     if (defined $libperl) {
@@ -2473,10 +2473,10 @@ MAP_PRELIBS   = $Config{perllibs} $Config{cryptlib}
 
         if (! -f $libperl and ! -f $lperl) {
           # We did not find a static libperl. Maybe there is a shared one?
-          if ($Is{SunOS}) {
-            $lperl  = $libperl = "$dir/$Config{libperl}";
+          if (%Is{SunOS}) {
+            $lperl  = $libperl = "$dir/%Config{libperl}";
             # SUNOS ld does not take the full path to a shared library
-            $libperl = '' if $Is{SunOS4};
+            $libperl = '' if %Is{SunOS4};
           }
         }
 
@@ -2572,7 +2572,7 @@ $(OBJECT) : $(FIRST_MAKEFILE)
 
 ' if $self->{OBJECT};
 
-    my $newer_than_target = $Is{VMS} ? '$(MMS$SOURCE_LIST)' : '$?';
+    my $newer_than_target = %Is{VMS} ? '$(MMS$SOURCE_LIST)' : '$?';
     my $mpl_args = join " ", map qq["$_"], @ARGV;
 
     $m .= sprintf <<'MAKE_FRAG', $newer_than_target, $mpl_args;
@@ -2618,7 +2618,7 @@ also has_link_code())
 sub needs_linking {
     my($self) = shift;
 
-    my $caller = (caller(0))[3];
+    my $caller = (caller(0))[[3]];
     confess("needs_linking called too early") if 
       $caller =~ m/^ExtUtils::MakeMaker::/;
     return $self->{NEEDS_LINKING} if defined $self->{NEEDS_LINKING};
@@ -2713,7 +2713,7 @@ sub parse_version {
         |;
         local $^W = 0;
         $result = eval($eval);  ## no critic
-        warn "Could not eval '$eval' in $parsefile: $@" if $@;
+        warn "Could not eval '$eval' in $parsefile: {$@->message}" if $@;
         last;
     }
     close $fh;
@@ -2735,7 +2735,7 @@ sub pasthru {
     my(@m);
 
     my(@pasthru);
-    my($sep) = $Is{VMS} ? ',' : '';
+    my($sep) = %Is{VMS} ? ',' : '';
     $sep .= "\\\n\t";
 
     foreach my $key (qw(LIB LIBPERL_A LINKTYPE OPTIMIZE
@@ -2947,7 +2947,7 @@ for a binary distribution.
 sub ppd {
     my($self) = @_;
 
-    my ($pack_ver) = join ",", (split (m/\./, $self->{VERSION}), (0)x4)[0..3];
+    my ($pack_ver) = join ",", (split (m/\./, $self->{VERSION}), (0)x4)[[0..3]];
 
     my $abstract = $self->{ABSTRACT} || '';
     $abstract =~ s/\n/\\n/sg;
@@ -2970,18 +2970,18 @@ PPD_HTML
         my $pre_req = $prereq;
         $pre_req =~ s/::/-/g;
         my ($dep_ver) = join ",", (split (m/\./, $self->{PREREQ_PM}{$prereq}), 
-                                  (0) x 4) [0 .. 3];
+                                  (0) x 4) [[0 .. 3]];
         $ppd_xml .= sprintf <<'PPD_OUT', $pre_req, $dep_ver;
         <DEPENDENCY NAME="%s" VERSION="%s" />
 PPD_OUT
 
     }
 
-    my $archname = $Config{archname};
+    my $archname = %Config{archname};
         # archname did not change from 5.6 to 5.8, but those versions may
         # not be not binary compatible so now we append the part of the
         # version that changes when binary compatibility may change
-        $archname .= "-". substr($Config{version},0,3);
+        $archname .= "-". substr(%Config{version},0,3);
     $ppd_xml .= sprintf <<'PPD_OUT', $archname;
         <OS NAME="$(OSNAME)" />
         <ARCHITECTURE NAME="%s" />
@@ -2989,11 +2989,11 @@ PPD_OUT
 
     if ($self->{PPM_INSTALL_SCRIPT}) {
         if ($self->{PPM_INSTALL_EXEC}) {
-            $ppd_xml .= sprintf qq{        <INSTALL EXEC="%s">%s</INSTALL>\n},
+            $ppd_xml .= sprintf qq{        <INSTALL EXEC="\%s">\%s</INSTALL>\n},
                   $self->{PPM_INSTALL_EXEC}, $self->{PPM_INSTALL_SCRIPT};
         }
         else {
-            $ppd_xml .= sprintf qq{        <INSTALL>%s</INSTALL>\n}, 
+            $ppd_xml .= sprintf qq{        <INSTALL>\%s</INSTALL>\n}, 
                   $self->{PPM_INSTALL_SCRIPT};
         }
     }
@@ -3047,7 +3047,7 @@ sub prefixify {
     my($self,$var,$sprefix,$rprefix,$default) = @_;
 
     my $path = $self->{uc $var} || 
-               $Config_Override{lc $var} || $Config{lc $var} || '';
+               %Config_Override{lc $var} || %Config{lc $var} || '';
 
     $rprefix .= '/' if $sprefix =~ m|/$|;
 
@@ -3088,7 +3088,7 @@ sub processPL {
 		     : [$pl_files->{$plfile}];
 
 	foreach my $target (@$list) {
-            if( $Is{VMS} ) {
+            if( %Is{VMS} ) {
                 $plfile = vmsify($self->eliminate_macros($plfile));
                 $target = vmsify($self->eliminate_macros($target));
             }
@@ -3407,7 +3407,7 @@ sub test {
 # --- Test and Installation Sections ---
 
     my($self, %attribs) = @_;
-    my $tests = $attribs{TESTS} || '';
+    my $tests = %attribs{TESTS} || '';
     if (!$tests && -d 't') {
         $tests = $self->find_tests;
     }
@@ -3572,9 +3572,9 @@ sub tool_xsubpp {
         unshift( @tmargs, $self->{XSOPT} );
     }
 
-    if ($Is{VMS}                          &&
-        $Config{'ldflags'}               && 
-        $Config{'ldflags'} =~ m!/Debug!i &&
+    if (%Is{VMS}                          &&
+        %Config{'ldflags'}               && 
+        %Config{'ldflags'} =~ m!/Debug!i &&
         (!exists($self->{XSOPT}) || $self->{XSOPT} !~ m/linenumbers/)
        ) 
     {
