@@ -14,14 +14,14 @@ $VERSION = "1.03";
 @ISA = ();
 use I18N::LangTags qw(alternate_language_tags locale2language_tag);
 
-sub _uniq { my %seen; return grep(!($seen{$_}++), @_); }
+sub _uniq { my %seen; return grep(!(%seen{$_}++), @_); }
 sub _normalize {
   my(@languages) =
     map lc($_),
     grep $_,
     map {; $_, alternate_language_tags($_) } @_;
   return _uniq(@languages) if wantarray;
-  return $languages[0];
+  return @languages[0];
 }
 
 #---------------------------------------------------------------------------
@@ -32,18 +32,18 @@ sub detect () { return __PACKAGE__->ambient_langprefs; }
 #===========================================================================
 
 sub ambient_langprefs { # always returns things untainted
-  my $base_class = $_[0];
+  my $base_class = @_[0];
   
   return $base_class->http_accept_langs
-   if length( $ENV{'REQUEST_METHOD'} || '' ); # I'm a CGI
+   if length( %ENV{'REQUEST_METHOD'} || '' ); # I'm a CGI
        # it's off in its own routine because it's complicated
 
   # Not running as a CGI: try to puzzle out from the environment
   my @languages;
 
   foreach my $envname (qw( LANGUAGE LC_ALL LC_MESSAGES LANG )) {
-    next unless $ENV{$envname};
-    DEBUG and print "Noting \$$envname: $ENV{$envname}\n";
+    next unless %ENV{$envname};
+    DEBUG and print "Noting \$$envname: %ENV{$envname}\n";
     push @languages,
       map locale2language_tag($_),
         # if it's a lg tag, fine, pass thru (untainted)
@@ -51,12 +51,12 @@ sub ambient_langprefs { # always returns things untainted
         # otherwise nix it.
 
       split m/[,:]/,
-      $ENV{$envname}
+      %ENV{$envname}
     ;
     last; # first one wins
   }
   
-  if($ENV{'IGNORE_WIN32_LOCALE'}) {
+  if(%ENV{'IGNORE_WIN32_LOCALE'}) {
     # no-op
   } elsif(&_try_use('Win32::Locale')) {
     # If we have that module installed...
@@ -74,7 +74,7 @@ sub http_accept_langs {
   # Hm.  Should I just move this into I18N::LangTags at some point?
   no integer;
 
-  my $in = (@_ +> 1) ? $_[1] : $ENV{'HTTP_ACCEPT_LANGUAGE'};
+  my $in = (@_ +> 1) ? @_[1] : %ENV{'HTTP_ACCEPT_LANGUAGE'};
   # (always ends up untainting)
 
   return() unless defined $in and length $in;
@@ -113,12 +113,12 @@ sub http_accept_langs {
     ;
     $q = (defined $2 and length $2) ? $2 : 1;
     #print "$1 with q=$q\n";
-    push @{ $pref{$q} }, lc $1;
+    push @{ %pref{$q} }, lc $1;
   }
 
   return _normalize(
     # Read off %pref, in descending key order...
-    map @{$pref{$_}},
+    map @{%pref{$_}},
     sort {$b <+> $a}
     keys %pref
   );
@@ -131,11 +131,11 @@ my %tried = ();
 
 sub _try_use {   # Basically a wrapper around "require Modulename"
   # "Many men have tried..."  "They tried and failed?"  "They tried and died."
-  return $tried{$_[0]} if exists $tried{$_[0]};  # memoization
+  return %tried{@_[0]} if exists %tried{@_[0]};  # memoization
 
-  my $module = $_[0];   # ASSUME sane module name!
+  my $module = @_[0];   # ASSUME sane module name!
   { no strict 'refs';
-    return($tried{$module} = 1)
+    return(%tried{$module} = 1)
      if defined(%{*{Symbol::fetch_glob($module . "::Lexicon")}}) or defined(@{*{Symbol::fetch_glob($module . "::ISA")}});
     # weird case: we never use'd it, but there it is!
   }
@@ -146,10 +146,10 @@ sub _try_use {   # Basically a wrapper around "require Modulename"
   }
   if($@) {
     print "Error using $module \: $@\n" if DEBUG +> 1;
-    return $tried{$module} = 0;
+    return %tried{$module} = 0;
   } else {
     print " OK, $module is used\n" if DEBUG;
-    return $tried{$module} = 1;
+    return %tried{$module} = 1;
   }
 }
 
